@@ -23,14 +23,11 @@
 #include "qtest_messagecomposer.h"
 #include "cryptofunctions.h"
 
-#include "testcsshelper.h"
-
-#include <QDebug>
-#include <qtest.h>
+#include "setupenv.h"
 
 #include <Libkleo/Enum>
 
-#include <kmime/kmime_headers.h>
+#include <KMime/Headers>
 using namespace KMime;
 
 #include <MessageComposer/Composer>
@@ -39,22 +36,23 @@ using namespace KMime;
 #include <MessageComposer/GlobalPart>
 #include <MessageComposer/InfoPart>
 #include <MessageComposer/TextPart>
-#include "MessageComposer/Util"
-#include <attachment/attachmentmodel.h>
-#include <attachment/attachmentcontrollerbase.h>
+#include <MessageComposer/Util>
+#include <MessageComposer/AttachmentControllerBase>
+#include <MessageComposer/AttachmentModel>
 using namespace MessageComposer;
 
 #include <MessageCore/AttachmentPart>
 #include <MessageCore/NodeHelper>
-#include <setupenv.h>
+using namespace MessageCore;
 
 #include <MimeTreeParser/ObjectTreeParser>
-#include <MimeTreeParser/BufferedHtmlWriter>
-
-using MessageCore::AttachmentPart;
+#include <MimeTreeParser/SimpleObjectTreeSource>
 
 #include <gpgme++/key.h>
 
+#include <QDebug>
+#include <QTest>
+
 Q_DECLARE_METATYPE(MessageCore::AttachmentPart)
 
 QTEST_MAIN(CryptoComposerTest)
@@ -74,7 +72,7 @@ void CryptoComposerTest::testOpenPGPMime_data()
     QTest::addColumn<bool>("encrypt");
     QTest::addColumn<Headers::contentEncoding>("cte");
 
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     QTest::newRow("SignOpenPGPMime") << data << true << false << Headers::CE7Bit;
     QTest::newRow("EncryptOpenPGPMime") << data << false << true << Headers::CE7Bit;
     QTest::newRow("SignEncryptOpenPGPMime") << data << true << true << Headers::CE7Bit;
@@ -124,7 +122,7 @@ void CryptoComposerTest::testEncryptSameAttachments()
 {
     QFETCH(int, format);
     Composer *composer = new Composer;
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
 
@@ -153,17 +151,12 @@ void CryptoComposerTest::testEncryptSameAttachments()
     QCOMPARE(message->from()->asUnicodeString(), QString::fromLocal8Bit("me@me.me"));
     QCOMPARE(message->to()->asUnicodeString(), QString::fromLocal8Bit("you@you.you"));
 
-    MimeTreeParser::BufferedHtmlWriter testWriter;
-    testWriter.begin();
-    TestCSSHelper testCSSHelper;
-    MessageComposer::Test::TestObjectTreeSource testSource(&testWriter, &testCSSHelper);
-    testSource.setAllowDecryption(true);
+    MimeTreeParser::SimpleObjectTreeSource testSource;
+    testSource.setDecryptMessage(true);
     MimeTreeParser::NodeHelper *nh = new MimeTreeParser::NodeHelper;
     MimeTreeParser::ObjectTreeParser otp(&testSource, nh);
-    MimeTreeParser::ProcessResult pResult(nh);
 
     otp.parseObjectTree(message.data());
-    testWriter.end();
     KMime::Message::Ptr unencrypted = nh->unencryptedMessage(message);
 
     KMime::Content *testAttachment = Util::findTypeInMessage(unencrypted.data(), "x-some", "x-type");
@@ -308,7 +301,7 @@ void CryptoComposerTest::testSignEncryptLateAttachments()
 {
     QFETCH(int, format);
     Composer *composer = new Composer;
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
 
@@ -339,7 +332,7 @@ void CryptoComposerTest::testSignEncryptLateAttachments()
     QCOMPARE(message->to()->asUnicodeString(), QString::fromLocal8Bit("you@you.you"));
 
     // now check the attachment separately
-    QCOMPARE(QString::fromAscii(MessageCore::NodeHelper::nextSibling(b)->body()), QString::fromAscii("abc"));
+    QCOMPARE(QString::fromLatin1(MessageCore::NodeHelper::nextSibling(b)->body()), QString::fromLatin1("abc"));
 }
 
 void CryptoComposerTest::testBCCEncrypt_data()
@@ -356,9 +349,9 @@ void CryptoComposerTest::testBCCEncrypt()
 {
     QFETCH(int, format);
     Composer *composer = new Composer;
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
-    composer->infoPart()->setBcc(QStringList(QString::fromLatin1("bcc@bcc.org")));
+    composer->infoPart()->setBcc(QStringList(QLatin1String("bcc@bcc.org")));
 
     std::vector<GpgME::Key> keys = MessageComposer::Test::getKeys();
 
@@ -411,7 +404,7 @@ void CryptoComposerTest::testOpenPGPInline_data()
     QTest::addColumn<bool>("encrypt");
     QTest::addColumn<Headers::contentEncoding>("cte");
 
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     QTest::newRow("SignOpenPGPInline") << data << true << false << Headers::CE7Bit;
     QTest::newRow("EncryptOpenPGPInline") << data << false << true << Headers::CE7Bit;
     QTest::newRow("SignEncryptOpenPGPInline") << data << true << true << Headers::CE7Bit;
@@ -440,7 +433,7 @@ void CryptoComposerTest::testOpenPGPInline()
     composer = nullptr;
 
     if (sign && !encrypt) {
-        data += QString::fromLatin1("\n");
+        data += QLatin1Char('\n');
     }
     //qDebug() << "message:" << message->encodedContent();
     ComposerTestUtil::verify(sign, encrypt, message.data(), data.toUtf8(),
@@ -459,7 +452,7 @@ void CryptoComposerTest::testSMIME_data()
     QTest::addColumn<bool>("encrypt");
     QTest::addColumn<Headers::contentEncoding>("cte");
 
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     QTest::newRow("SignSMIME") << data << true << false << Headers::CE7Bit;
     QTest::newRow("EncryptSMIME") << data << false << true << Headers::CE7Bit;
     QTest::newRow("SignEncryptSMIME") << data << true << true << Headers::CE7Bit;
@@ -480,7 +473,7 @@ void CryptoComposerTest::testSMIMEOpaque_data()
     QTest::addColumn<bool>("encrypt");
     QTest::addColumn<Headers::contentEncoding>("cte");
 
-    QString data(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     QTest::newRow("SignSMIMEOpaque") << data << true << false << Headers::CE7Bit;
     QTest::newRow("EncryptSMIMEOpaque") << data << false << true << Headers::CE7Bit;
     QTest::newRow("SignEncryptSMIMEOpaque") << data << true << true << Headers::CE7Bit;
@@ -546,11 +539,11 @@ void CryptoComposerTest::testCTEbase64()
 }
 
 // Helper methods
-void CryptoComposerTest::fillComposerData(Composer *composer, QString data)
+void CryptoComposerTest::fillComposerData(Composer *composer, const QString &data)
 {
     composer->globalPart()->setFallbackCharsetEnabled(true);
-    composer->infoPart()->setFrom(QString::fromLatin1("me@me.me"));
-    composer->infoPart()->setTo(QStringList(QString::fromLatin1("you@you.you")));
+    composer->infoPart()->setFrom(QStringLiteral("me@me.me"));
+    composer->infoPart()->setTo(QStringList(QLatin1String("you@you.you")));
     composer->textPart()->setWrappedPlainText(data);
 }
 
@@ -578,7 +571,7 @@ void CryptoComposerTest::runSMIMETest(bool sign, bool enc, bool opaque)
     Composer *composer = new Composer;
 
     fillComposerData(composer, data);
-    composer->infoPart()->setFrom(QString::fromLatin1("test@example.com"));
+    composer->infoPart()->setFrom(QStringLiteral("test@example.com"));
 
     std::vector<GpgME::Key> keys = MessageComposer::Test::getKeys(true);
     QStringList recipients;
