@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,7 @@
 
 #include "followupreminderselectdatedialogtest.h"
 #include "../src/followupreminder/followupreminderselectdatedialog.h"
-#include <qtest.h>
+#include <QTest>
 #include <KDateComboBox>
 #include <AkonadiWidgets/CollectionComboBox>
 
@@ -27,7 +27,7 @@
 #include <QPushButton>
 #include <AkonadiCore/EntityTreeModel>
 #include <QStandardItemModel>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Todo>
 
 FollowupReminderSelectDateDialogTest::FollowupReminderSelectDateDialogTest(QObject *parent)
     : QObject(parent)
@@ -45,7 +45,7 @@ QStandardItemModel *FollowupReminderSelectDateDialogTest::defaultItemModel()
         Akonadi::Collection collection(id);
         collection.setRights(Akonadi::Collection::AllRights);
         collection.setName(QString::number(id));
-        collection.setContentMimeTypes(QStringList() << KCalCore::Todo::todoMimeType());
+        collection.setContentMimeTypes(QStringList() << KCalendarCore::Todo::todoMimeType());
 
         QStandardItem *item = new QStandardItem(collection.name());
         item->setData(QVariant::fromValue(collection),
@@ -67,7 +67,7 @@ void FollowupReminderSelectDateDialogTest::shouldHaveDefaultValue()
     Akonadi::CollectionComboBox *combobox = dlg.findChild<Akonadi::CollectionComboBox *>(QStringLiteral("collectioncombobox"));
     QVERIFY(combobox);
     QDate currentDate = QDate::currentDate();
-    QCOMPARE(datecombobox->date(), currentDate);
+    QCOMPARE(datecombobox->date(), currentDate.addDays(1));
 
     QPushButton *okButton = dlg.findChild<QPushButton *>(QStringLiteral("ok_button"));
     QVERIFY(okButton);
