@@ -1,7 +1,7 @@
 /*
   Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (c) 2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -21,42 +21,51 @@
 
 #include "messagefactoryngtest.h"
 
+#include "qtest_messagecomposer.h"
 #include "cryptofunctions.h"
+#include "setupenv.h"
 
 #include <MessageCore/StringUtil>
-#include <MessageCore/NodeHelper>
 
-#include "MessageComposer/Composer"
-#include "MessageComposer/MessageFactoryNG"
-#include "MessageComposer/GlobalPart"
-#include "MessageComposer/MessageComposerSettings"
-#include "MessageComposer/Util"
+#include <MessageComposer/Composer>
+#include <MessageComposer/MessageFactoryNG>
+#include <MessageComposer/GlobalPart>
+#include <MessageComposer/MessageComposerSettings>
+#include <MessageComposer/Util>
 
-#include "MessageComposer/InfoPart"
-#include "MessageComposer/TextPart"
+#include <MessageComposer/InfoPart>
+#include <MessageComposer/TextPart>
 
-#include "testcsshelper.h"
-#include <setupenv.h>
+#include <KMime/DateFormatter>
 
-#include <MimeTreeParser/BufferedHtmlWriter>
-#include <MimeTreeParser/NodeHelper>
-#include <MimeTreeParser/ObjectTreeParser>
+#include <KIdentityManagement/KIdentityManagement/IdentityManager>
+#include <KIdentityManagement/KIdentityManagement/Identity>
 
-#include "qtest_messagecomposer.h"
-#include <kmime/kmime_dateformatter.h>
+#include "globalsettings_templateparser.h"
 
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
-#include <KIdentityManagement/kidentitymanagement/identity.h>
-#include <qtest.h>
-#include <QDateTime>
 #include <KCharsets>
+
+#include <QDateTime>
 #include <QDir>
 #include <QLocale>
-#include "globalsettings_templateparser.h"
 #include <QSignalSpy>
+#include <QTest>
 
 using namespace MessageComposer;
 
+MessageFactoryTest::MessageFactoryTest(QObject *parent)
+    : QObject(parent)
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
+MessageFactoryTest::~MessageFactoryTest()
+{
+    // Workaround QTestLib not flushing deleteLater()s on exit, which
+    // leads to WebEngine asserts (view not deleted)
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
+}
+
 #ifndef Q_OS_WIN
 void initLocale()
 {
@@ -141,20 +150,16 @@ void MessageFactoryTest::cleanupTestCase()
 
 void MessageFactoryTest::initTestCase()
 {
-    // Force fake XDG dirs so that KIdentityManagement does not
-    // read actual user data when running tests locally
-    QStandardPaths::setTestModeEnabled(true);
     qRegisterMetaType<MessageComposer::MessageFactoryNG::MessageReply>();
     mIdentMan = new KIdentityManagement::IdentityManager;
 
-    KIdentityManagement::Identity &ident = mIdentMan->modifyIdentityForUoid(mIdentMan->identityForUoidOrDefault(0).uoid());
+    KIdentityManagement::Identity &ident = mIdentMan->modifyIdentityForUoid(mIdentMan->defaultIdentity().uoid());
     ident.setFullName(QStringLiteral("another"));
     ident.setPrimaryEmailAddress(QStringLiteral("another@another.com"));
 
     mIdentMan->newFromScratch(QStringLiteral("test1"));
     mIdentMan->newFromScratch(QStringLiteral("test2"));
     mIdentMan->newFromScratch(QStringLiteral("test3"));
-    mIdentMan->setAsDefault(ident.uoid());
     mIdentMan->commit();
 }
 
@@ -199,7 +204,6 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderAndIdentityInCCAsync()
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
 
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -212,8 +216,8 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderAndIdentityInCCAsync()
     QString ba = QString::fromLatin1("From: foo1 <identity1@bla.com>\n"
                                      "X-KMail-Identity: %1\n"
                                      "Date: %2\n"
-                                     "Cc: blo <blo@blo.org>, bli <bli@bli.org>, blu <blu@blu.org>, bly <bly@bly.org>, Bla <identity1@bla.com>\n"
-                                     "To: Bla <identity1@bla.com>\n"
+                                     "Cc: blu <blu@blu.org>, bly <bly@bly.org>\n"
+                                     "To: blo <blo@blo.org>, bli <bli@bli.org>\n"
                                      "Subject: Re: Plain Message Test\n"
                                      "Content-Type: text/plain; charset=\"US-ASCII\"\n"
                                      "Content-Transfer-Encoding: 8Bit\nMIME-Version: 1.0\n"
@@ -248,7 +252,6 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderAsync()
 
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -260,8 +263,8 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderAsync()
     QString dateStr = reply.msg->date()->asUnicodeString();
     QString ba = QString::fromLatin1("From: another <another@another.com>\n"
                                      "Date: %1\n"
-                                     "Cc: blo <blo@blo.org>, bli <bli@bli.org>, blu <blu@blu.org>, bly <bly@bly.org>\n"
-                                     "To: Bla <identity1@bla.com>\n"
+                                     "Cc: blu <blu@blu.org>, bly <bly@bly.org>\n"
+                                     "To: blo <blo@blo.org>, bli <bli@bli.org>\n"
                                      "Subject: Re: Plain Message Test\n"
                                      "Content-Type: text/plain; charset=\"US-ASCII\"\n"
                                      "Content-Transfer-Encoding: 8Bit\nMIME-Version: 1.0\n"
@@ -296,7 +299,6 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderByNoSameIdentitiesAsyn
 
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -308,8 +310,8 @@ void MessageFactoryTest::testCreateReplyToAllWithUseSenderByNoSameIdentitiesAsyn
     QString dateStr = reply.msg->date()->asUnicodeString();
     QString ba = QString::fromLatin1("From: another <another@another.com>\n"
                                      "Date: %1\n"
-                                     "Cc: blo <blo@blo.org>, bli <bli@bli.org>, blu <blu@blu.org>, bly <bly@bly.org>\n"
-                                     "To: Bla <bloblo@bla.com>\n"
+                                     "Cc: blu <blu@blu.org>, bly <bly@bly.org>\n"
+                                     "To: blo <blo@blo.org>, bli <bli@bli.org>, Bla <bloblo@bla.com>\n"
                                      "Subject: Re: Plain Message Test\n"
                                      "Content-Type: text/plain; charset=\"US-ASCII\"\n"
                                      "Content-Transfer-Encoding: 8Bit\nMIME-Version: 1.0\n"
@@ -374,7 +376,6 @@ void MessageFactoryTest::testCreateReplyToAuthorAsync()
 
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -419,7 +420,6 @@ void MessageFactoryTest::testCreateReplyAllWithMultiEmailsAsync()
 
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -434,8 +434,8 @@ void MessageFactoryTest::testCreateReplyAllWithMultiEmailsAsync()
     QString ba = QString::fromLatin1("From: another <another@another.com>\n"
                                      "Date: %1\n"
                                      "X-KMail-Transport: 0\n"
-                                     "Cc: you@you.you, you2@you.you, cc@cc.cc, cc2@cc.cc\n"
-                                     "To: me@me.me\n"
+                                     "Cc: cc@cc.cc, cc2@cc.cc\n"
+                                     "To: you@you.you, you2@you.you, me@me.me\n"
                                      "References: %3\n"
                                      "In-Reply-To: %2\n"
                                      "Subject: Re: Test Email Subject\nContent-Type: text/plain; charset=\"US-ASCII\"\n"
@@ -458,7 +458,6 @@ void MessageFactoryTest::testCreateReplyAllAsync()
     QCOMPARE(spy.count(), 1);
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << reply.msg->body();
 
     QDateTime date = msg->date()->dateTime();
     QString datetime = QLocale::system().toString(date.date(), QLocale::LongFormat);
@@ -487,7 +486,6 @@ void MessageFactoryTest::testCreateReplyHtmlAsync()
     QCOMPARE(spy.count(), 1);
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-    //qDebug() << "html reply" << reply.msg->encodedContent();
 
     QDateTime date = msg->date()->dateTime().toLocalTime();
     QString datetime = QLocale().toString(date.date(), QLocale::LongFormat);
@@ -518,7 +516,6 @@ void MessageFactoryTest::testCreateReplyUTF16Base64Async()
     KMime::Message::Ptr msg = loadMessageFromFile(QStringLiteral("plain_utf16.mbox"));
 
     TemplateParser::TemplateParserSettings::self()->setReplyUsingHtml(true);
-//   qDebug() << "plain base64 msg message:" << msg->encodedContent();
 
     MessageFactoryNG factory(msg, 0);
     factory.setIdentityManager(mIdentMan);
@@ -531,7 +528,6 @@ void MessageFactoryTest::testCreateReplyUTF16Base64Async()
     QCOMPARE(spy.count(), 1);
     MessageFactoryNG::MessageReply reply = spy.at(0).at(0).value<MessageComposer::MessageFactoryNG::MessageReply>();
     reply.replyAll = true;
-//   qDebug() << "html reply" << reply.msg->encodedContent();
 
     QDateTime date = msg->date()->dateTime().toLocalTime();
     QString datetime = QLocale().toString(date.date(), QLocale::LongFormat);
@@ -581,7 +577,6 @@ void MessageFactoryTest::testCreateForwardMultiEmailsAsync()
         "-----------------------------------------");
     fwdMsg = fwdMsg.arg(datetime).arg(fw->date()->asUnicodeString());
 
-//   qDebug() << "got:" << fw->encodedContent() << "against" << fwdMsg.toLatin1();
     QCOMPARE(fw->subject()->asUnicodeString(), QStringLiteral("Fwd: Test Email Subject"));
     QCOMPARE_OR_DIFF(fw->encodedContent(), fwdMsg.toLatin1());
 }
@@ -626,7 +621,6 @@ void MessageFactoryTest::testCreateForwardAsync()
         "-----------------------------------------");
     fwdMsg = fwdMsg.arg(datetime).arg(fw->date()->asUnicodeString());
 
-//   qDebug() << "got:" << fw->encodedContent() << "against" << fwdMsg.toLatin1();
     QCOMPARE(fw->subject()->asUnicodeString(), QStringLiteral("Fwd: Test Email Subject"));
     QCOMPARE_OR_DIFF(fw->encodedContent(), fwdMsg.toLatin1());
 }
@@ -645,15 +639,11 @@ void MessageFactoryTest::testCreateRedirectToAndCCAndBCC()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-//   qDebug() << rdir->encodedContent();
-
-
-    QRegExp rx(QString::fromLatin1("Resent-Message-ID: ([^\n]*)"));
+    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
     rx.indexIn(QString::fromLatin1(rdir->head()));
 
-    QRegExp rxmessageid(QString::fromLatin1("Message-ID: ([^\n]+)"));
+    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
     rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
-    //qWarning() << "messageid:" << rxmessageid.cap(1) << "(" << rdir->head() << ")";
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "Cc: cc@cc.cc\n"
                                            "Bcc: bcc@bcc.bcc\n"
@@ -677,10 +667,6 @@ void MessageFactoryTest::testCreateRedirectToAndCCAndBCC()
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
     baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
-//   qDebug() << baseline.toLatin1();
-//   qDebug() << "instead:" << rdir->encodedContent();
-
-//   QString fwdStr = QString::fromLatin1( "On " + datetime.toLatin1() + " you wrote:\n> All happy families are alike; each unhappy family is unhappy in its own way.\n" );
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
 }
@@ -698,14 +684,12 @@ void MessageFactoryTest::testCreateRedirectToAndCC()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-//   qDebug() << rdir->encodedContent();
-
     QString msgId = MessageCore::StringUtil::generateMessageId(msg->sender()->asUnicodeString(), QString());
 
-    QRegExp rx(QString::fromLatin1("Resent-Message-ID: ([^\n]*)"));
+    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
     rx.indexIn(QString::fromLatin1(rdir->head()));
 
-    QRegExp rxmessageid(QString::fromLatin1("Message-ID: ([^\n]+)"));
+    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
     rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
     //qWarning() << "messageid:" << rxmessageid.cap(1) << "(" << rdir->head() << ")";
     QString baseline = QString::fromLatin1("From: me@me.me\n"
@@ -730,10 +714,6 @@ void MessageFactoryTest::testCreateRedirectToAndCC()
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
     baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
-//   qDebug() << baseline.toLatin1();
-//   qDebug() << "instead:" << rdir->encodedContent();
-
-//   QString fwdStr = QString::fromLatin1( "On " + datetime.toLatin1() + " you wrote:\n> All happy families are alike; each unhappy family is unhappy in its own way.\n" );
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
 }
@@ -750,14 +730,11 @@ void MessageFactoryTest::testCreateRedirect()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-//   qDebug() << rdir->encodedContent();
-
-    QRegExp rx(QString::fromLatin1("Resent-Message-ID: ([^\n]*)"));
+    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
     rx.indexIn(QString::fromLatin1(rdir->head()));
 
-    QRegExp rxmessageid(QString::fromLatin1("Message-ID: ([^\n]+)"));
+    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
     rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
-    //qWarning() << "messageid:" << rxmessageid.cap(1) << "(" << rdir->head() << ")";
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "Cc: cc@cc.cc\n"
                                            "Bcc: bcc@bcc.bcc\n"
@@ -779,10 +756,6 @@ void MessageFactoryTest::testCreateRedirect()
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
     baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
-//   qDebug() << baseline.toLatin1();
-//   qDebug() << "instead:" << rdir->encodedContent();
-
-//   QString fwdStr = QString::fromLatin1( "On " + datetime.toLatin1() + " you wrote:\n> All happy families are alike; each unhappy family is unhappy in its own way.\n" );
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
 }
@@ -798,12 +771,10 @@ void MessageFactoryTest::testCreateResend()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-//   qDebug() << msg->encodedContent();
-
-    QRegExp rx(QString::fromLatin1("Resent-Message-ID: ([^\n]*)"));
+    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
     rx.indexIn(QString::fromLatin1(rdir->head()));
 
-    QRegExp rxmessageid(QString::fromLatin1("Message-ID: ([^\n]+)"));
+    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
     rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
 
     QString baseline = QString::fromLatin1("From: me@me.me\n"
@@ -822,10 +793,6 @@ void MessageFactoryTest::testCreateResend()
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
     baseline = baseline.arg(msg->to()->asUnicodeString()).arg(datetime).arg(rxmessageid.cap(1));
 
-    //qDebug() << baseline.toLatin1();
-    //qDebug() << "instead:" << rdir->encodedContent();
-
-//   QString fwdStr = QString::fromLatin1( "On " + datetime.toLatin1() + " you wrote:\n> All happy families are alike; each unhappy family is unhappy in its own way.\n" );
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
 }
@@ -841,23 +808,12 @@ void MessageFactoryTest::testCreateMDN()
     KMime::Message::Ptr mdn = factory.createMDN(KMime::MDN::AutomaticAction, KMime::MDN::Displayed, KMime::MDN::SentAutomatically);
 
     QVERIFY(mdn.data());
-    //qDebug() << "mdn" << mdn->encodedContent();
-    /*
-      // parse the result and make sure it is valid in various ways
-      TestHtmlWriter testWriter;
-      TestCSSHelper testCSSHelper;
-      TestObjectTreeSource testSource( &testWriter, &testCSSHelper );
-      MimeTreeParser::NodeHelper* nh = new MimeTreeParser::NodeHelper;
-      MimeTreeParser::ObjectTreeParser otp( &testSource, nh, 0, false, true, 0 );
-      MimeTreeParser::ProcessResult pResult( nh ); */
 
     QString mdnContent = QString::fromLatin1("The message sent on %1 to %2 with subject \"%3\" has been displayed. "
                                              "This is no guarantee that the message has been read or understood.");
-    mdnContent = mdnContent.arg(KMime::DateFormatter::formatDate(KMime::DateFormatter::Localized, msg->date()->dateTime().toTime_t()))
+    mdnContent = mdnContent.arg(KMime::DateFormatter::formatDate(KMime::DateFormatter::Localized, msg->date()->dateTime().toSecsSinceEpoch()))
                  .arg(msg->to()->asUnicodeString()).arg(msg->subject()->asUnicodeString());
 
-    //qDebug() << "comparing with:" << mdnContent;
-
     QCOMPARE_OR_DIFF(Util::findTypeInMessage(mdn.data(), "multipart", "report")->contents().at(0)->body(),
                      mdnContent.toLatin1());
 }
@@ -866,11 +822,11 @@ KMime::Message::Ptr MessageFactoryTest::createPlainTestMessage()
 {
     Composer *composer = new Composer;
     composer->globalPart()->setFallbackCharsetEnabled(true);
-    composer->infoPart()->setFrom(QString::fromLatin1("me@me.me"));
-    composer->infoPart()->setTo(QStringList(QString::fromLatin1("you@you.you")));
-    composer->infoPart()->setCc(QStringList(QString::fromLatin1("cc@cc.cc")));
-    composer->infoPart()->setBcc(QStringList(QString::fromLatin1("bcc@bcc.bcc")));
-    composer->textPart()->setWrappedPlainText(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    composer->infoPart()->setFrom(QStringLiteral("me@me.me"));
+    composer->infoPart()->setTo(QStringList(QLatin1String("you@you.you")));
+    composer->infoPart()->setCc(QStringList(QLatin1String("cc@cc.cc")));
+    composer->infoPart()->setBcc(QStringList(QLatin1String("bcc@bcc.bcc")));
+    composer->textPart()->setWrappedPlainText(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     composer->infoPart()->setSubject(QStringLiteral("Test Email Subject"));
     composer->globalPart()->setMDNRequested(true);
     composer->exec();
@@ -887,11 +843,11 @@ KMime::Message::Ptr MessageFactoryTest::createPlainTestMessageWithMultiEmails()
 {
     Composer *composer = new Composer;
     composer->globalPart()->setFallbackCharsetEnabled(true);
-    composer->infoPart()->setFrom(QString::fromLatin1("me@me.me"));
+    composer->infoPart()->setFrom(QStringLiteral("me@me.me"));
     composer->infoPart()->setTo(QStringList() << QStringLiteral("you@you.you") << QStringLiteral("you2@you.you"));
     composer->infoPart()->setCc(QStringList() << QStringLiteral("cc@cc.cc") << QStringLiteral("cc2@cc.cc"));
     composer->infoPart()->setBcc(QStringList() << QStringLiteral("bcc@bcc.bcc") << QStringLiteral("bcc2@bcc.bcc"));
-    composer->textPart()->setWrappedPlainText(QString::fromLatin1("All happy families are alike; each unhappy family is unhappy in its own way."));
+    composer->textPart()->setWrappedPlainText(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     composer->infoPart()->setSubject(QStringLiteral("Test Email Subject"));
     composer->globalPart()->setMDNRequested(true);
     composer->exec();
@@ -926,7 +882,8 @@ void MessageFactoryTest::test_multipartAlternative_data()
     QTest::addColumn<QString>("expected");
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
-    foreach (const QString &file, dir.entryList(QStringList(QLatin1String("plain_message.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks)) {
+    const QStringList lst = dir.entryList(QStringList(QStringLiteral("plain_message.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
+    for (const QString &file : lst) {
         QTest::newRow(file.toLatin1().constData()) << QString(dir.path() + QLatin1Char('/') + file) << 0 << ""
                                                    <<"> This *is* the *message* text *from* Sudhendu Kumar<dontspamme@yoohoo.com>\n"
             "> \n"
