@@ -29,8 +29,8 @@
 
 void MessageComposer::Test::setupEnv()
 {
-    setenv("LC_ALL", "C", 1);
-    setenv("KDEHOME", QFile::encodeName(QDir::homePath() + QString::fromLatin1("/.qttest")).constData(), 1);
+    qputenv("LC_ALL", "C");
+    qputenv("KDEHOME", QFile::encodeName(QDir::homePath() + QLatin1String("/.qttest")).constData());
 }
 
 std::vector< GpgME::Key, std::allocator< GpgME::Key > > MessageComposer::Test::getKeys(bool smime)
