@@ -26,6 +26,7 @@
 #include "MessageComposer/AttachmentJob"
 #include "MessageComposer/AttachmentFromPublicKeyJob"
 #include "MessageComposer/AttachmentVcardFromAddressBookJob"
+#include "MessageComposer/AttachmentClipBoardJob"
 #include "MessageComposer/Composer"
 #include "MessageComposer/GlobalPart"
 
@@ -43,6 +44,7 @@
 #include <QMenu>
 #include <QPointer>
 #include <QTreeView>
+#include <QUrlQuery>
 
 #include <QAction>
 #include <KActionCollection>
@@ -62,11 +64,10 @@
 #include <Libkleo/KeySelectionDialog>
 
 #include <MessageCore/AttachmentCompressJob>
-#include <MessageCore/AttachmentFromFolderJob>
-#include <MessageCore/AttachmentFromMimeContentJob>
-#include <MessageCore/AttachmentFromUrlJob>
+#include "attachment/attachmentfrommimecontentjob.h"
+#include "attachment/attachmentfromurljob.h"
 #include <MessageCore/AttachmentPropertiesDialog>
-#include <MessageCore/AttachmentUpdateJob>
+#include "messagecore/attachmentupdatejob.h"
 #include <MessageCore/AttachmentFromUrlUtils>
 #include <settings/messagecomposersettings.h>
 #include <KIO/Job>
@@ -100,20 +101,19 @@ public:
     void slotAttachmentContentCreated(KJob *job);   // slot
     void addAttachmentPart(AttachmentPart::Ptr part);
     void attachVcardFromAddressBook(KJob *job);   //slot
+    void attachClipBoardElement(KJob *job);
     void selectedAllAttachment();
     void createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part);
     void reloadAttachment();
     void updateJobResult(KJob *);
 
+    AttachmentPart::List selectedParts;
     AttachmentControllerBase *const q;
-    bool encryptEnabled = false;
-    bool signEnabled = false;
     MessageComposer::AttachmentModel *model = nullptr;
     QWidget *wParent = nullptr;
     QHash<MessageViewer::EditorWatcher *, AttachmentPart::Ptr> editorPart;
     QHash<MessageViewer::EditorWatcher *, QTemporaryFile *> editorTempFile;
 
-    AttachmentPart::List selectedParts;
     KActionCollection *mActionCollection = nullptr;
     QAction *attachPublicKeyAction = nullptr;
     QAction *attachMyPublicKeyAction = nullptr;
@@ -135,9 +135,11 @@ public:
     QAction *addOwnVcardAction = nullptr;
     QAction *reloadAttachmentAction = nullptr;
     QAction *attachVCardsAction = nullptr;
-
+    QAction *attachClipBoardAction = nullptr;
     // If part p is compressed, uncompressedParts[p] is the uncompressed part.
     QHash<AttachmentPart::Ptr, AttachmentPart::Ptr> uncompressedParts;
+    bool encryptEnabled = false;
+    bool signEnabled = false;
 };
 
 AttachmentControllerBase::Private::Private(AttachmentControllerBase *qq)
@@ -182,7 +184,6 @@ void AttachmentControllerBase::Private::compressJobResult(KJob *job)
 
     Q_ASSERT(dynamic_cast<AttachmentCompressJob *>(job));
     AttachmentCompressJob *ajob = static_cast<AttachmentCompressJob *>(job);
-    //AttachmentPart *originalPart = const_cast<AttachmentPart*>( ajob->originalPart() );
     AttachmentPart::Ptr originalPart = ajob->originalPart();
     AttachmentPart::Ptr compressedPart = ajob->compressedPart();
 
@@ -275,7 +276,9 @@ void AttachmentControllerBase::Private::reloadAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
     AttachmentUpdateJob *ajob = new AttachmentUpdateJob(selectedParts.first(), q);
-    connect(ajob, SIGNAL(result(KJob*)), q, SLOT(updateJobResult(KJob*)));
+    connect(ajob, &AttachmentUpdateJob::result, q, [this](KJob *job) {
+        updateJobResult(job);
+    });
     ajob->start();
 }
 
@@ -371,7 +374,9 @@ void AttachmentControllerBase::exportPublicKey(const QString &fingerprint)
     }
 
     MessageComposer::AttachmentFromPublicKeyJob *ajob = new MessageComposer::AttachmentFromPublicKeyJob(fingerprint, this);
-    connect(ajob, &AttachmentFromPublicKeyJob::result, this, [this](KJob *job) {d->attachPublicKeyJobResult(job); });
+    connect(ajob, &AttachmentFromPublicKeyJob::result, this, [this](KJob *job) {
+        d->attachPublicKeyJobResult(job);
+    });
     ajob->start();
 }
 
@@ -394,7 +399,8 @@ void AttachmentControllerBase::Private::attachPublicKeyJobResult(KJob *job)
 void AttachmentControllerBase::Private::attachVcardFromAddressBook(KJob *job)
 {
     if (job->error()) {
-        qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get vcard";
+        qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get vCard";
+        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach vCard"));
         return;
     }
 
@@ -403,6 +409,19 @@ void AttachmentControllerBase::Private::attachVcardFromAddressBook(KJob *job)
     q->addAttachment(part);
 }
 
+void AttachmentControllerBase::Private::attachClipBoardElement(KJob *job)
+{
+    if (job->error()) {
+        qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get try to attach text from clipboard";
+        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach text from clipboard"));
+        return;
+    }
+
+    MessageComposer::AttachmentClipBoardJob *ajob = static_cast<MessageComposer::AttachmentClipBoardJob *>(job);
+    AttachmentPart::Ptr part = ajob->attachmentPart();
+    q->addAttachment(part);
+}
+
 static QTemporaryFile *dumpAttachmentToTempFile(const AttachmentPart::Ptr &part)   // local
 {
     QTemporaryFile *file = new QTemporaryFile;
@@ -427,7 +446,9 @@ AttachmentControllerBase::AttachmentControllerBase(MessageComposer::AttachmentMo
     d->model = model;
     connect(model, &MessageComposer::AttachmentModel::attachUrlsRequested, this, &AttachmentControllerBase::addAttachments);
     connect(model, &MessageComposer::AttachmentModel::attachmentRemoved,
-            this, [this](const MessageCore::AttachmentPart::Ptr &attr) { d->attachmentRemoved(attr); });
+            this, [this](const MessageCore::AttachmentPart::Ptr &attr) {
+        d->attachmentRemoved(attr);
+    });
     connect(model, &AttachmentModel::attachmentCompressRequested,
             this, &AttachmentControllerBase::compressAttachment);
     connect(model, &MessageComposer::AttachmentModel::encryptEnabled, this, &AttachmentControllerBase::setEncryptEnabled);
@@ -477,53 +498,81 @@ void AttachmentControllerBase::createActions()
     d->attachVCardsAction->setIconText(i18n("Attach"));
     connect(d->attachVCardsAction, &QAction::triggered, this, &AttachmentControllerBase::showAttachVcard);
 
+    d->attachClipBoardAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-attachment")), i18n("&Attach Text From Clipboard..."), this);
+    d->attachClipBoardAction->setIconText(i18n("Attach Text From Clipboard"));
+    connect(d->attachClipBoardAction, &QAction::triggered, this, &AttachmentControllerBase::showAttachClipBoard);
+
     d->attachmentMenu->addAction(d->addAttachmentFileAction);
     d->attachmentMenu->addAction(d->addAttachmentDirectoryAction);
     d->attachmentMenu->addSeparator();
     d->attachmentMenu->addAction(d->addOwnVcardAction);
     d->attachmentMenu->addSeparator();
     d->attachmentMenu->addAction(d->attachVCardsAction);
+    d->attachmentMenu->addSeparator();
+    d->attachmentMenu->addAction(d->attachClipBoardAction);
 
     d->removeAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Remove Attachment"), this);
     d->removeContextAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), this);     // FIXME need two texts. is there a better way?
-    connect(d->removeAction, &QAction::triggered, this, [this]() { d->removeSelectedAttachments(); });
-    connect(d->removeContextAction, &QAction::triggered, this, [this]() { d->removeSelectedAttachments(); });
+    connect(d->removeAction, &QAction::triggered, this, [this]() {
+        d->removeSelectedAttachments();
+    });
+    connect(d->removeContextAction, &QAction::triggered, this, [this]() {
+        d->removeSelectedAttachments();
+    });
 
     d->openContextAction = new QAction(i18nc("to open", "Open"), this);
-    connect(d->openContextAction, SIGNAL(triggered(bool)), this, SLOT(openSelectedAttachments()));
+    connect(d->openContextAction, &QAction::triggered, this, [this]() {
+        d->openSelectedAttachments();
+    });
 
     d->viewContextAction = new QAction(i18nc("to view", "View"), this);
-    connect(d->viewContextAction, SIGNAL(triggered(bool)), this, SLOT(viewSelectedAttachments()));
+    connect(d->viewContextAction, &QAction::triggered, this, [this]() {
+        d->viewSelectedAttachments();
+    });
 
     d->editContextAction = new QAction(i18nc("to edit", "Edit"), this);
-    connect(d->editContextAction, SIGNAL(triggered(bool)), this, SLOT(editSelectedAttachment()));
+    connect(d->editContextAction, &QAction::triggered, this, [this]() {
+        d->editSelectedAttachment();
+    });
 
     d->editWithContextAction = new QAction(i18n("Edit With..."), this);
-    connect(d->editWithContextAction, SIGNAL(triggered(bool)), this, SLOT(editSelectedAttachmentWith()));
+    connect(d->editWithContextAction, &QAction::triggered, this, [this]() {
+        d->editSelectedAttachmentWith();
+    });
 
     d->saveAsAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
                                   i18n("&Save Attachment As..."), this);
     d->saveAsContextAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
                                          i18n("Save As..."), this);
-    connect(d->saveAsAction, SIGNAL(triggered(bool)),
-            this, SLOT(saveSelectedAttachmentAs()));
-    connect(d->saveAsContextAction, SIGNAL(triggered(bool)),
-            this, SLOT(saveSelectedAttachmentAs()));
+    connect(d->saveAsAction, &QAction::triggered,
+            this, [this]() {
+        d->saveSelectedAttachmentAs();
+    });
+    connect(d->saveAsContextAction, &QAction::triggered,
+            this, [this]() {
+        d->saveSelectedAttachmentAs();
+    });
 
     d->propertiesAction = new QAction(i18n("Attachment Pr&operties..."), this);
     d->propertiesContextAction = new QAction(i18n("Properties"), this);
-    connect(d->propertiesAction, SIGNAL(triggered(bool)),
-            this, SLOT(selectedAttachmentProperties()));
-    connect(d->propertiesContextAction, SIGNAL(triggered(bool)),
-            this, SLOT(selectedAttachmentProperties()));
+    connect(d->propertiesAction, &QAction::triggered,
+            this, [this]() {
+        d->selectedAttachmentProperties();
+    });
+    connect(d->propertiesContextAction, &QAction::triggered,
+            this, [this]() {
+        d->selectedAttachmentProperties();
+    });
 
     d->selectAllAction = new QAction(i18n("Select All"), this);
     connect(d->selectAllAction, &QAction::triggered,
             this, &AttachmentControllerBase::selectedAllAttachment);
 
     d->reloadAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Reload"), this);
-    connect(d->reloadAttachmentAction, SIGNAL(triggered(bool)),
-            this, SLOT(reloadAttachment()));
+    connect(d->reloadAttachmentAction, &QAction::triggered,
+            this, [this]() {
+        d->reloadAttachment();
+    });
 
     // Insert the actions into the composer window's menu.
     KActionCollection *collection = d->mActionCollection;
@@ -560,7 +609,9 @@ void AttachmentControllerBase::compressAttachment(const AttachmentPart::Ptr &par
         qCDebug(MESSAGECOMPOSER_LOG) << "Compressing part.";
 
         AttachmentCompressJob *ajob = new AttachmentCompressJob(part, this);
-        connect(ajob, SIGNAL(result(KJob*)), this, SLOT(compressJobResult(KJob*)));
+        connect(ajob, &AttachmentCompressJob::result, this, [this](KJob *job) {
+            d->compressJobResult(job);
+        });
         ajob->start();
     } else {
         qCDebug(MESSAGECOMPOSER_LOG) << "Uncompressing part.";
@@ -580,7 +631,7 @@ void AttachmentControllerBase::showContextMenu()
     Q_EMIT refreshSelection();
 
     const int numberOfParts(d->selectedParts.count());
-    QMenu *menu = new QMenu;
+    QMenu menu;
 
     const bool enableEditAction = (numberOfParts == 1)
                                   && (!d->selectedParts.first()->isMessageOrMessageCollection());
@@ -597,44 +648,43 @@ void AttachmentControllerBase::showContextMenu()
             if ((mimetype == QLatin1String("text/plain"))
                 || (mimetype == QLatin1String("image/png"))
                 || (mimetype == QLatin1String("image/jpeg"))
-                || parentMimeType.contains(QStringLiteral("text/plain"))
-                || parentMimeType.contains(QStringLiteral("image/png"))
-                || parentMimeType.contains(QStringLiteral("image/jpeg"))
+                || parentMimeType.contains(QLatin1String("text/plain"))
+                || parentMimeType.contains(QLatin1String("image/png"))
+                || parentMimeType.contains(QLatin1String("image/jpeg"))
                 ) {
-                menu->addAction(d->viewContextAction);
+                menu.addAction(d->viewContextAction);
             }
-            d->createOpenWithMenu(menu, d->selectedParts.first());
+            d->createOpenWithMenu(&menu, d->selectedParts.first());
         }
-        menu->addAction(d->openContextAction);
+        menu.addAction(d->openContextAction);
     }
     if (enableEditAction) {
-        menu->addAction(d->editWithContextAction);
-        menu->addAction(d->editContextAction);
+        menu.addAction(d->editWithContextAction);
+        menu.addAction(d->editContextAction);
     }
     if (numberOfParts > 0) {
-        menu->addAction(d->removeContextAction);
+        menu.addAction(d->removeContextAction);
     }
     if (numberOfParts == 1) {
         if (!d->selectedParts.first()->url().isEmpty()) {
-            menu->addAction(d->reloadAttachmentAction);
+            menu.addAction(d->reloadAttachmentAction);
         }
-        menu->addAction(d->saveAsContextAction);
-        menu->addSeparator();
-        menu->addAction(d->propertiesContextAction);
+        menu.addAction(d->saveAsContextAction);
+        menu.addSeparator();
+        menu.addAction(d->propertiesContextAction);
     }
 
     const int nbAttachment = d->model->rowCount();
     if (nbAttachment != numberOfParts) {
-        menu->addSeparator();
-        menu->addAction(d->selectAllAction);
+        menu.addSeparator();
+        menu.addAction(d->selectAllAction);
     }
     if (numberOfParts == 0) {
-        menu->addSeparator();
-        menu->addAction(d->addContextAction);
+        menu.addSeparator();
+        menu.addAction(d->addContextAction);
     }
 
-    menu->exec(QCursor::pos());
-    delete menu;
+    menu.exec(QCursor::pos());
 }
 
 void AttachmentControllerBase::slotOpenWithDialog()
@@ -718,8 +768,9 @@ void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
     MessageComposer::Composer *composer = new MessageComposer::Composer;
     composer->globalPart()->setFallbackCharsetEnabled(true);
     MessageComposer::AttachmentJob *attachmentJob = new MessageComposer::AttachmentJob(part, composer);
-    connect(attachmentJob, SIGNAL(result(KJob*)),
-            this, SLOT(slotAttachmentContentCreated(KJob*)));
+    connect(attachmentJob, &AttachmentJob::result, this, [this](KJob *job) {
+        d->slotAttachmentContentCreated(job);
+    });
     attachmentJob->start();
 }
 
@@ -751,8 +802,10 @@ void AttachmentControllerBase::editAttachment(AttachmentPart::Ptr part, MessageV
         QUrl::fromLocalFile(tempFile->fileName()),
         QString::fromLatin1(part->mimeType()), openWithOption,
         this, d->wParent);
-    connect(watcher, SIGNAL(editDone(MessageViewer::EditorWatcher*)),
-            this, SLOT(editDone(MessageViewer::EditorWatcher*)));
+    connect(watcher, &MessageViewer::EditorWatcher::editDone,
+            this, [this](MessageViewer::EditorWatcher *watcher)  {
+        d->editDone(watcher);
+    });
 
     switch (watcher->start()) {
     case MessageViewer::EditorWatcher::NoError:
@@ -865,13 +918,24 @@ void AttachmentControllerBase::showAttachVcard()
         const Akonadi::EmailAddressSelection::List selectedEmail = dlg->selectedAddresses();
         for (const Akonadi::EmailAddressSelection &selected : selectedEmail) {
             MessageComposer::AttachmentVcardFromAddressBookJob *ajob = new MessageComposer::AttachmentVcardFromAddressBookJob(selected.item(), this);
-            connect(ajob, &AttachmentVcardFromAddressBookJob::result, this, [this](KJob *job) {d->attachVcardFromAddressBook(job);});
+            connect(ajob, &AttachmentVcardFromAddressBookJob::result, this, [this](KJob *job) {
+                d->attachVcardFromAddressBook(job);
+            });
             ajob->start();
         }
     }
     delete dlg;
 }
 
+void AttachmentControllerBase::showAttachClipBoard()
+{
+    MessageComposer::AttachmentClipBoardJob *job = new MessageComposer::AttachmentClipBoardJob(this);
+    connect(job, &AttachmentClipBoardJob::result, this, [this](KJob *job) {
+        d->attachClipBoardElement(job);
+    });
+    job->start();
+}
+
 void AttachmentControllerBase::showAddAttachmentCompressedDirectoryDialog()
 {
     const QUrl url = QFileDialog::getExistingDirectoryUrl(d->wParent, i18nc("@title:window", "Attach Directory"));
@@ -934,7 +998,9 @@ void AttachmentControllerBase::addAttachmentUrlSync(const QUrl &url)
 void AttachmentControllerBase::addAttachment(const QUrl &url)
 {
     MessageCore::AttachmentFromUrlBaseJob *ajob = MessageCore::AttachmentFromUrlUtils::createAttachmentJob(url, this);
-    connect(ajob, SIGNAL(result(KJob*)), this, SLOT(loadJobResult(KJob*)));
+    connect(ajob, &AttachmentFromUrlBaseJob::result, this, [this](KJob *job) {
+        d->loadJobResult(job);
+    });
     ajob->start();
 }
 
