@@ -277,7 +277,7 @@ QVariant AttachmentModel::data(const QModelIndex &index, int role) const
                   part->name().isEmpty() ? part->fileName() : part->name(),
                   KFormat().formatByteSize(part->size()),
                   KMime::nameForEncoding(part->encoding()),
-                  QString::fromAscii(part->mimeType().data())));
+                  QString::fromLatin1(part->mimeType().data())));
     } else if (role == Qt::CheckStateRole) {
         switch (index.column()) {
         case CompressColumn:
@@ -369,17 +369,23 @@ bool AttachmentModel::setData(const QModelIndex &index, const QVariant &value, i
     return true;
 }
 
-bool AttachmentModel::addAttachment(AttachmentPart::Ptr part)
+void AttachmentModel::addAttachment(const AttachmentPart::Ptr &part)
 {
     Q_ASSERT(!d->parts.contains(part));
+    if (!part->url().isEmpty()) {
+        for (const AttachmentPart::Ptr &partElement : qAsConst(d->parts)) {
+            if (partElement->url() == part->url()) {
+                return;
+            }
+        }
+    }
 
     beginInsertRows(QModelIndex(), rowCount(), rowCount());
     d->parts.append(part);
     endInsertRows();
-    return true;
 }
 
-bool AttachmentModel::updateAttachment(AttachmentPart::Ptr part)
+bool AttachmentModel::updateAttachment(const AttachmentPart::Ptr &part)
 {
     int idx = d->parts.indexOf(part);
     if (idx == -1) {
@@ -391,7 +397,7 @@ bool AttachmentModel::updateAttachment(AttachmentPart::Ptr part)
     return true;
 }
 
-bool AttachmentModel::replaceAttachment(AttachmentPart::Ptr oldPart, AttachmentPart::Ptr newPart)
+bool AttachmentModel::replaceAttachment(const AttachmentPart::Ptr &oldPart, const AttachmentPart::Ptr &newPart)
 {
     Q_ASSERT(oldPart != newPart);
 
