@@ -25,20 +25,22 @@
 #include "messagecomposer_export.h"
 #include <LibkdepimAkonadi/AddresseeLineEdit>
 namespace MessageComposer {
+/**
+ * @brief The ComposerLineEdit class
+ */
 class MESSAGECOMPOSER_EXPORT ComposerLineEdit : public KPIM::AddresseeLineEdit
 {
     Q_OBJECT
 
 public:
     explicit ComposerLineEdit(bool useCompletion, QWidget *parent = nullptr);
-    ~ComposerLineEdit();
+    ~ComposerLineEdit() override;
 
 Q_SIGNALS:
     void focusUp();
     void focusDown();
 
 protected:
-
     void keyPressEvent(QKeyEvent *) override;
 };
 }
