@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,9 +26,6 @@ using namespace MessageComposer;
 
 MessageFactoryForwardJob::MessageFactoryForwardJob(QObject *parent)
     : QObject(parent)
-    , mMsg(nullptr)
-    , mOrigMsg(nullptr)
-    , mIdentityManager(nullptr)
 {
 }
 
