@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,8 @@
 
 #include "imagescaling.h"
 #include "settings/messagecomposersettings.h"
-
+#include <QImage>
+#include <QBuffer>
 using namespace MessageComposer;
 
 class MessageComposer::ImageScalingPrivate
