@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -17,20 +17,20 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef AUTORESIZEIMAGEUTIL_H
-#define AUTORESIZEIMAGEUTIL_H
+#ifndef IMAGESCALINGUTILS_H
+#define IMAGESCALINGUTILS_H
 #include <MessageCore/AttachmentPart>
 
 namespace MessageComposer {
 class Utils
 {
 public:
-    bool containsImage(const MessageCore::AttachmentPart::List &parts);
-    bool resizeImage(MessageCore::AttachmentPart::Ptr part);
+    Q_REQUIRED_RESULT bool containsImage(const MessageCore::AttachmentPart::List &parts);
+    Q_REQUIRED_RESULT bool resizeImage(MessageCore::AttachmentPart::Ptr part);
     void changeFileName(MessageCore::AttachmentPart::Ptr part);
-    bool filterRecipients(const QStringList &recipients);
-    bool hasImage(const QByteArray &mimetype);
+    Q_REQUIRED_RESULT bool filterRecipients(const QStringList &recipients);
+    Q_REQUIRED_RESULT bool hasImage(const QByteArray &mimetype);
 };
 }
 
-#endif // AUTORESIZEIMAGEUTIL_H
+#endif // IMAGESCALINGUTILS_H
