@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -51,3 +51,8 @@ int PluginEditor::order() const
 {
     return d->order;
 }
+
+bool PluginEditor::canProcessKeyEvent() const
+{
+    return false;
+}
