@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,6 +24,10 @@
 #include <PimCommon/AbstractGenericPlugin>
 namespace MessageComposer {
 class PluginEditorPrivate;
+/**
+ * @brief The PluginEditor class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT PluginEditor : public PimCommon::AbstractGenericPlugin
 {
     Q_OBJECT
@@ -31,8 +35,9 @@ public:
     explicit PluginEditor(QObject *parent = nullptr);
     ~PluginEditor();
     void setOrder(int order);
-    int order() const;
+    Q_REQUIRED_RESULT int order() const;
 
+    virtual Q_REQUIRED_RESULT bool canProcessKeyEvent() const;
 private:
     PluginEditorPrivate *const d;
 };
