@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,11 +36,11 @@ public:
     {
     }
 
+    PimCommon::PluginUtilData pluginData;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
-    PimCommon::PluginUtilData pluginData;
-    int order = 0;
     PluginEditor *plugin = nullptr;
+    int order = 0;
     bool isEnabled = true;
 };
 
@@ -61,12 +61,12 @@ public:
     }
 
     void loadPlugin(PluginEditorInfo *item);
-    QVector<PluginEditor *> pluginsList() const;
-    QVector<PimCommon::PluginUtilData> pluginDataList() const;
-    bool initializePlugins();
+    Q_REQUIRED_RESULT QVector<PluginEditor *> pluginsList() const;
+    Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginDataList() const;
+    void initializePlugins();
 
-    QString configGroupName() const;
-    QString configPrefixSettingKey() const;
+    Q_REQUIRED_RESULT QString configGroupName() const;
+    Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     PluginEditor *pluginFromIdentifier(const QString &id);
 private:
     QVector<PluginEditorInfo> mPluginList;
@@ -74,10 +74,10 @@ private:
     PluginEditorManager *q;
 };
 
-bool PluginEditorManagerPrivate::initializePlugins()
+void PluginEditorManagerPrivate::initializePlugins()
 {
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kmail"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QStringLiteral("KMailEditor/Plugin"));
+        return md.serviceTypes().contains(QLatin1String("KMailEditor/Plugin"));
     });
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
@@ -118,7 +118,6 @@ bool PluginEditorManagerPrivate::initializePlugins()
     for (QVector<PluginEditorInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
         loadPlugin(&(*it));
     }
-    return true;
 }
 
 void PluginEditorManagerPrivate::loadPlugin(PluginEditorInfo *item)
