@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,6 +24,10 @@
 #include <QWidget>
 
 namespace MessageComposer {
+/**
+ * @brief The PluginEditorInitConfigureWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT PluginEditorInitConfigureWidget : public QWidget
 {
     Q_OBJECT
@@ -34,7 +38,7 @@ public:
     virtual void loadSettings() = 0;
     virtual void saveSettings() = 0;
     virtual void resetSettings() = 0;
-    virtual QString helpAnchor() const;
+    Q_REQUIRED_RESULT virtual QString helpAnchor() const;
 Q_SIGNALS:
     void configureChanged();
 };
