@@ -37,6 +37,9 @@
 namespace MessageComposer {
 /** Represents a mail recipient. */
 class RecipientPrivate;
+/**
+ * @brief The Recipient class
+ */
 class MESSAGECOMPOSER_EXPORT Recipient : public KPIM::MultiplyingLineData
 {
 public:
@@ -44,7 +47,7 @@ public:
     typedef QList<Recipient::Ptr> List;
 
     enum Type {
-        To, Cc, Bcc, Undefined
+        To, Cc, Bcc, ReplyTo, Undefined
     };
 
     Recipient(const QString &email = QString(), Type type = To);   //krazy:exclude=explicit
