@@ -32,8 +32,11 @@ namespace KLDAP {
 class LdapSearchDialog;
 }
 
-namespace MessageComposer {
+namespace Akonadi {
 class RecipientsPickerWidget;
+}
+
+namespace MessageComposer {
 class RecipientsPicker : public QDialog
 {
     Q_OBJECT
@@ -61,17 +64,19 @@ protected Q_SLOTS:
     void slotToClicked();
     void slotCcClicked();
     void slotBccClicked();
+    void slotReplyToClicked();
     void slotPicked();
     void slotSearchLDAP();
     void ldapSearchResult();
     void slotSelectionChanged();
 
 private:
-    MessageComposer::RecipientsPickerWidget *mView = nullptr;
+    Akonadi::RecipientsPickerWidget *mView = nullptr;
 
     KLDAP::LdapSearchDialog *mLdapSearchDialog = nullptr;
 
     Recipient::Type mDefaultType;
+    QPushButton *mUser4Button = nullptr;
     QPushButton *mUser3Button = nullptr;
     QPushButton *mUser2Button = nullptr;
     QPushButton *mUser1Button = nullptr;
