@@ -30,13 +30,16 @@ class KJob;
 
 namespace MessageComposer {
 class AkonadiSenderPrivate;
+/**
+ * @brief The AkonadiSender class
+ */
 class MESSAGECOMPOSER_EXPORT AkonadiSender : public QObject, public MessageSender
 {
     Q_OBJECT
 
 public:
     explicit AkonadiSender(QObject *parent = nullptr);
-    ~AkonadiSender();
+    ~AkonadiSender() override;
 
 protected:
     /**
@@ -50,13 +53,13 @@ protected:
 
     TODO cberzan: update docu...
     */
-    bool doSend(const KMime::Message::Ptr &msg, short sendNow) override;
+    Q_REQUIRED_RESULT bool doSend(const KMime::Message::Ptr &msg, short sendNow) override;
 
     /**
     Send queued messages, using the specified transport or the
     default, if none is given.
     */
-    bool doSendQueued(int transportId = -1) override;
+    Q_REQUIRED_RESULT bool doSendQueued(int transportId = -1) override;
 
 private:
     /**
