@@ -23,7 +23,7 @@
 #include <QBuffer>
 #include "messagecore_debug.h"
 #include <KZip>
-#include <qtest.h>
+#include <QTest>
 
 #include <MessageCore/AttachmentCompressJob>
 using namespace MessageCore;
@@ -84,8 +84,8 @@ void AttachmentCompressJobTest::testCompressedSizeLarger()
 {
     // Some data.
     QByteArray data("This is short enough that compressing it is not efficient.");
-    const QString name = QString::fromLatin1("name.txt");
-    const QString description = QString::fromLatin1("description");
+    const QString name = QStringLiteral("name.txt");
+    const QString description = QStringLiteral("description");
 
     // Create the original part.
     AttachmentPart::Ptr origPart = AttachmentPart::Ptr(new AttachmentPart);
