@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,16 +25,20 @@
 #include "attachmentpart.h"
 
 namespace MessageCore {
+/**
+ * @brief The AttachmentUpdateJob class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECORE_EXPORT AttachmentUpdateJob : public KJob
 {
     Q_OBJECT
 public:
-    AttachmentUpdateJob(const AttachmentPart::Ptr &part, QObject *parent = nullptr);
-    ~AttachmentUpdateJob();
+    explicit AttachmentUpdateJob(const AttachmentPart::Ptr &part, QObject *parent = nullptr);
+    ~AttachmentUpdateJob() override;
 
     void start() override;
-    AttachmentPart::Ptr originalPart() const;
-    AttachmentPart::Ptr updatedPart() const;
+    Q_REQUIRED_RESULT AttachmentPart::Ptr originalPart() const;
+    Q_REQUIRED_RESULT AttachmentPart::Ptr updatedPart() const;
 private:
     //@cond PRIVATE
     class Private;
