@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
    Copyright 2009 Thomas McGuire <mcguire@kde.org>
 
    This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 #include "stringutil.h"
 
@@ -172,25 +172,51 @@ static bool flushPart(QString &msg, QStringList &textParts, const QString &inden
     return appendEmptyLine;
 }
 
-QMap<QString, QString> parseMailtoUrl(const QUrl &url)
+QList<QPair<QString, QString> > parseMailtoUrl(const QUrl &url)
 {
-    QMap<QString, QString> values;
+    QList<QPair<QString, QString> > values;
     if (url.scheme() != QLatin1String("mailto")) {
         return values;
     }
-    QUrlQuery query(url);
-    Q_FOREACH (const auto &queryItem, query.queryItems(QUrl::FullyDecoded)) {
-        values.insertMulti(queryItem.first, queryItem.second);
+    QString str = url.toString();
+    QString toStr;
+    int i = 0;
+    int indexTo = -1;
+    //Workaround line with # see bug 406208
+    const int indexOf = str.indexOf(QLatin1Char('?'));
+    if (indexOf != -1) {
+        str = str.right(str.length() - indexOf - 1);
+        QUrlQuery query(str);
+        const auto listQuery = query.queryItems(QUrl::FullyDecoded);
+        for (const auto &queryItem : listQuery) {
+            if (queryItem.first == QLatin1String("to")) {
+                toStr = queryItem.second;
+                indexTo = i;
+            } else {
+                QPair<QString, QString> pairElement;
+                pairElement.first = queryItem.first;
+                pairElement.second = queryItem.second;
+                values.append(pairElement);
+            }
+            i++;
+        }
     }
-
     QStringList to = {KEmailAddress::decodeMailtoUrl(url)};
 
-    const QString toStr = values.value(QStringLiteral("to"));
     if (!toStr.isEmpty()) {
         to << toStr;
     }
-
-    values.insert(QStringLiteral("to"), to.join(QStringLiteral(", ")));
+    const QString fullTo = to.join(QLatin1String(", "));
+    if (!fullTo.isEmpty()) {
+        QPair<QString, QString> pairElement;
+        pairElement.first = QStringLiteral("to");
+        pairElement.second = fullTo;
+        if (indexTo != -1) {
+            values.insert(indexTo, pairElement);
+        } else {
+            values.prepend(pairElement);
+        }
+    }
     return values;
 }
 
@@ -332,8 +358,6 @@ void removePrivateHeaderFields(const KMime::Message::Ptr &message, bool cleanUpH
     message->removeHeader("X-Status");
     message->removeHeader("X-KMail-EncryptionState");
     message->removeHeader("X-KMail-SignatureState");
-    message->removeHeader("X-KMail-Transport");
-    message->removeHeader("X-KMail-Fcc");
     message->removeHeader("X-KMail-Redirect-From");
     message->removeHeader("X-KMail-Link-Message");
     message->removeHeader("X-KMail-Link-Type");
@@ -344,10 +368,15 @@ void removePrivateHeaderFields(const KMime::Message::Ptr &message, bool cleanUpH
     message->removeHeader("X-KMail-UnExpanded-To");
     message->removeHeader("X-KMail-UnExpanded-CC");
     message->removeHeader("X-KMail-UnExpanded-BCC");
+    message->removeHeader("X-KMail-UnExpanded-Reply-To");
     message->removeHeader("X-KMail-FccDisabled");
 
     if (cleanUpHeader) {
+        message->removeHeader("X-KMail-Fcc");
+        message->removeHeader("X-KMail-Transport");
         message->removeHeader("X-KMail-Identity");
+        message->removeHeader("X-KMail-Transport-Name");
+        message->removeHeader("X-KMail-Identity-Name");
         message->removeHeader("X-KMail-Dictionary");
     }
 }
@@ -422,22 +451,22 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList, Displa
     }
 
     if (link == ShowLink) {
-        result.truncate(result.length() - 2);
+        result.chop(2);
     }
 
     if (expandableInserted) {
-        result += QStringLiteral("<label class=\"addresslist_label_full\" for=\"%1\"></label></span>").arg(fieldName);
+        result += QStringLiteral("<label class=\"addresslist_label_full\" for=\"%1\"></label></span></span>").arg(fieldName);
     }
     return result;
 }
 
-QString emailAddrAsAnchor(KMime::Headers::Generics::MailboxList *mailboxList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
+QString emailAddrAsAnchor(const KMime::Headers::Generics::MailboxList *mailboxList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
 {
     Q_ASSERT(mailboxList);
     return emailAddrAsAnchor(mailboxList->mailboxes(), display, cssStyle, link, expandable, fieldName, collapseNumber);
 }
 
-QString emailAddrAsAnchor(KMime::Headers::Generics::AddressList *addressList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
+QString emailAddrAsAnchor(const KMime::Headers::Generics::AddressList *addressList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
 {
     Q_ASSERT(addressList);
     return emailAddrAsAnchor(addressList->mailboxes(), display, cssStyle, link, expandable, fieldName, collapseNumber);
@@ -599,7 +628,7 @@ QString formatQuotePrefix(const QString &wildString, const QString &fromDisplayS
             ch = wildString[i++];
             switch (ch.toLatin1()) {
             case 'f':
-            {           // sender's initals
+            {           // sender's initials
                 if (fromDisplayString.isEmpty()) {
                     break;
                 }
@@ -674,24 +703,67 @@ QString cleanFileName(const QString &name)
     return fileName;
 }
 
+QString cleanSubject(KMime::Message *msg)
+{
+    return cleanSubject(msg, MessageCore::MessageCoreSettings::self()->replyPrefixes() + MessageCore::MessageCoreSettings::self()->forwardPrefixes(),
+                        true, QString()).trimmed();
+}
+
+QString cleanSubject(KMime::Message *msg, const QStringList &prefixRegExps, bool replace, const QString &newPrefix)
+{
+    return replacePrefixes(msg->subject()->asUnicodeString(), prefixRegExps, replace,
+                           newPrefix);
+}
+
+QString forwardSubject(KMime::Message *msg)
+{
+    return cleanSubject(msg, MessageCore::MessageCoreSettings::self()->forwardPrefixes(),
+                        MessageCore::MessageCoreSettings::self()->replaceForwardPrefix(), QStringLiteral("Fwd:"));
+}
+
+QString replySubject(KMime::Message *msg)
+{
+    return cleanSubject(msg, MessageCore::MessageCoreSettings::self()->replyPrefixes(),
+                        MessageCore::MessageCoreSettings::self()->replaceReplyPrefix(), QStringLiteral("Re:"));
+}
+
+QString replacePrefixes(const QString &str, const QStringList &prefixRegExps, bool replace, const QString &newPrefix)
+{
+    bool recognized = false;
+    // construct a big regexp that
+    // 1. is anchored to the beginning of str (sans whitespace)
+    // 2. matches at least one of the part regexps in prefixRegExps
+    QString bigRegExp = QStringLiteral("^(?:\\s+|(?:%1))+\\s*")
+                        .arg(prefixRegExps.join(QStringLiteral(")|(?:")));
+    QRegExp rx(bigRegExp, Qt::CaseInsensitive);
+    if (rx.isValid()) {
+        QString tmp = str;
+        if (rx.indexIn(tmp) == 0) {
+            recognized = true;
+            if (replace) {
+                return tmp.replace(0, rx.matchedLength(), newPrefix + QLatin1Char(' '));
+            }
+        }
+    } else {
+        qCWarning(MESSAGECORE_LOG) << "bigRegExp = \""
+                                   << bigRegExp << "\"\n"
+                                   << "prefix regexp is invalid!";
+        // try good ole Re/Fwd:
+        recognized = str.startsWith(newPrefix);
+    }
+
+    if (!recognized) {
+        return newPrefix + QLatin1Char(' ') + str;
+    } else {
+        return str;
+    }
+}
+
 QString stripOffPrefixes(const QString &subject)
 {
-    static QStringList defaultReplyPrefixes = QStringList() << QStringLiteral("Re\\s*:")
-                                                            << QStringLiteral("Re\\[\\d+\\]:")
-                                                            << QStringLiteral("Re\\d+:");
+    const QStringList replyPrefixes = MessageCoreSettings::self()->replyPrefixes();
 
-    static QStringList defaultForwardPrefixes = QStringList() << QStringLiteral("Fwd:")
-                                                              << QStringLiteral("FW:");
-
-    QStringList replyPrefixes = MessageCoreSettings::self()->replyPrefixes();
-    if (replyPrefixes.isEmpty()) {
-        replyPrefixes = defaultReplyPrefixes;
-    }
-
-    QStringList forwardPrefixes = MessageCoreSettings::self()->forwardPrefixes();
-    if (forwardPrefixes.isEmpty()) {
-        forwardPrefixes = defaultForwardPrefixes;
-    }
+    const QStringList forwardPrefixes = MessageCoreSettings::self()->forwardPrefixes();
 
     const QStringList prefixRegExps = replyPrefixes + forwardPrefixes;
 
@@ -726,7 +798,9 @@ QString stripOffPrefixes(const QString &subject)
 
 void setEncodingFile(QUrl &url, const QString &encoding)
 {
-    url.addQueryItem(QStringLiteral("charset"), encoding);
+    QUrlQuery query;
+    query.addQueryItem(QStringLiteral("charset"), encoding);
+    url.setQuery(query);
 }
 }
 }
