@@ -34,7 +34,7 @@ using namespace MessageList::Core;
 //
 // Theme versioning
 //
-// The themes simply have a DWORD version number attacched.
+// The themes simply have a DWORD version number attached.
 // The earliest version we're able to load is 0x1013.
 //
 // Theme revision history:
@@ -491,7 +491,7 @@ bool Theme::Row::LoadContentItem(int val, QDataStream &stream, int themeVersion,
 
         // Add the annotation item next to the attachment icon, so that users upgrading from old
         // versions don't manually need to set this.
-        // Don't do this for the stand-alone attchment column.
+        // Don't do this for the stand-alone attachment column.
         if (ci->type() == ContentItem::AttachmentStateIcon
             && themeVersion < gThemeMinimumVersionWithAnnotationIcon
             && val > 1) {
@@ -818,9 +818,9 @@ void Theme::Column::save(QDataStream &stream) const
     stream << mPixmapName;
     stream << mVisibleByDefault;
     stream << mIsSenderOrReceiver;
-    stream << (int)mMessageSorting;
+    stream << static_cast<int>(mMessageSorting);
 
-    stream << (int)mGroupHeaderRows.count();
+    stream << static_cast<int>(mGroupHeaderRows.count());
 
     int cnt = mGroupHeaderRows.count();
 
@@ -830,7 +830,7 @@ void Theme::Column::save(QDataStream &stream) const
     }
 
     cnt = mMessageRows.count();
-    stream << (int)cnt;
+    stream << static_cast<int>(cnt);
 
     for (int i = 0; i < cnt; ++i) {
         Row *row = mMessageRows.at(i);
@@ -959,6 +959,7 @@ Theme::Theme(const Theme &src)
 
 Theme::~Theme()
 {
+    clearPixmapCache();
     removeAllColumns();
 }
 
@@ -1064,39 +1065,39 @@ void Theme::setGroupHeaderBackgroundStyle(Theme::GroupHeaderBackgroundStyle grou
 QList<QPair<QString, int> > Theme::enumerateViewHeaderPolicyOptions()
 {
     return { {
-                 i18n("Never Show"), NeverShowHeader
-             },
-             {
-                 i18n("Always Show"), ShowHeaderAlways
-             } };
+        i18n("Never Show"), NeverShowHeader
+    },
+        {
+            i18n("Always Show"), ShowHeaderAlways
+        } };
 }
 
 QList<QPair<QString, int> > Theme::enumerateGroupHeaderBackgroundStyles()
 {
     return { {
-                 i18n("Plain Rectangles"), PlainRect
-             },
-             {
-                 i18n("Plain Joined Rectangle"), PlainJoinedRect
-             },
-             {
-                 i18n("Rounded Rectangles"), RoundedRect
-             },
-             {
-                 i18n("Rounded Joined Rectangle"), RoundedJoinedRect
-             },
-             {
-                 i18n("Gradient Rectangles"), GradientRect
-             },
-             {
-                 i18n("Gradient Joined Rectangle"), GradientJoinedRect
-             },
-             {
-                 i18n("Styled Rectangles"), StyledRect
-             },
-             {
-                 i18n("Styled Joined Rectangles"), StyledJoinedRect
-             } };
+        i18n("Plain Rectangles"), PlainRect
+    },
+        {
+            i18n("Plain Joined Rectangle"), PlainJoinedRect
+        },
+        {
+            i18n("Rounded Rectangles"), RoundedRect
+        },
+        {
+            i18n("Rounded Joined Rectangle"), RoundedJoinedRect
+        },
+        {
+            i18n("Gradient Rectangles"), GradientRect
+        },
+        {
+            i18n("Gradient Joined Rectangle"), GradientJoinedRect
+        },
+        {
+            i18n("Styled Rectangles"), StyledRect
+        },
+        {
+            i18n("Styled Joined Rectangles"), StyledJoinedRect
+        } };
 }
 
 Theme::ViewHeaderPolicy Theme::viewHeaderPolicy() const
@@ -1147,7 +1148,7 @@ bool Theme::load(QDataStream &stream)
     int val;
 
     stream >> val;
-    mGroupHeaderBackgroundMode = (GroupHeaderBackgroundMode)val;
+    mGroupHeaderBackgroundMode = static_cast<GroupHeaderBackgroundMode>(val);
     switch (mGroupHeaderBackgroundMode) {
     case Transparent:
     case AutoColor:
@@ -1157,13 +1158,12 @@ bool Theme::load(QDataStream &stream)
     default:
         qCDebug(MESSAGELIST_LOG) << "Invalid theme group header background mode";
         return false; // b0rken
-        break;
     }
 
     stream >> mGroupHeaderBackgroundColor;
 
     stream >> val;
-    mGroupHeaderBackgroundStyle = (GroupHeaderBackgroundStyle)val;
+    mGroupHeaderBackgroundStyle = static_cast<GroupHeaderBackgroundStyle>(val);
     switch (mGroupHeaderBackgroundStyle) {
     case PlainRect:
     case PlainJoinedRect:
@@ -1178,7 +1178,6 @@ bool Theme::load(QDataStream &stream)
     default:
         qCDebug(MESSAGELIST_LOG) << "Invalid theme group header background style";
         return false; // b0rken
-        break;
     }
 
     stream >> val;
@@ -1191,7 +1190,6 @@ bool Theme::load(QDataStream &stream)
     default:
         qCDebug(MESSAGELIST_LOG) << "Invalid theme view header policy";
         return false; // b0rken
-        break;
     }
 
     if (themeVersion >= gThemeMinimumVersionWithIconSizeField) {
