@@ -16,8 +16,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#ifndef __MESSAGELIST_PANE_H__
-#define __MESSAGELIST_PANE_H__
+#ifndef MESSAGELIST_PANE_H
+#define MESSAGELIST_PANE_H
 
 #include <messagelist/enums.h>
 #include <messagelist/view.h>
@@ -61,7 +61,7 @@ public:
     * Create a Pane wrapping the specified model and selection.
     */
     explicit Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = nullptr);
-    ~Pane();
+    ~Pane() override;
 
     virtual MessageList::StorageModel *createStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent);
 
@@ -335,6 +335,8 @@ public:
     * If the specified folder is not open yet then behaviour
     * depends on the preferEmptyTab value as follows.
     *
+    * @param etmIndex the index for the collection in the EntityTreeModel (source model)
+    *
     * If preferEmptyTab is set to false then the (new) folder is loaded
     * in the current tab. If preferEmptyTab is set to true then the (new) folder is
     * loaded in the first empty tab (or a new one if there are no empty ones).
@@ -347,8 +349,7 @@ public:
     * like "loading..."
     */
     void setCurrentFolder(
-        const Akonadi::Collection &fld, bool preferEmptyTab = false, MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected,
-        const QString &overrideLabel = QString());
+        const Akonadi::Collection &fld, const QModelIndex &etmIndex, bool preferEmptyTab = false, MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected, const QString &overrideLabel = QString());
 
     void resetModelStorage();
 
@@ -428,24 +429,12 @@ Q_SIGNALS:
     */
     void currentTabChanged();
 
+    void forceLostFocus();
+
 private:
     void restoreHeaderSettings(int index);
     void readConfig(bool restoreSession);
 
-    Q_PRIVATE_SLOT(d, void onSelectionChanged(const QItemSelection &, const QItemSelection &))
-    Q_PRIVATE_SLOT(d, void onCloseTabClicked())
-    Q_PRIVATE_SLOT(d, void activateTab())
-    Q_PRIVATE_SLOT(d, void moveTabLeft())
-    Q_PRIVATE_SLOT(d, void moveTabRight())
-    Q_PRIVATE_SLOT(d, void activateNextTab())
-    Q_PRIVATE_SLOT(d, void activatePreviousTab())
-    Q_PRIVATE_SLOT(d, void closeTab(QWidget *))
-    Q_PRIVATE_SLOT(d, void onCurrentTabChanged())
-    Q_PRIVATE_SLOT(d, void onTabContextMenuRequest(const QPoint &))
-    Q_PRIVATE_SLOT(d, void updateTabControls())
-    Q_PRIVATE_SLOT(d, void changeQuicksearchVisibility(bool))
-    Q_PRIVATE_SLOT(d, void slotTabCloseRequested(int index))
-
     bool eventFilter(QObject *obj, QEvent *event) override;
 
     class Private;
@@ -453,4 +442,4 @@ private:
 };
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_PANE_H__
+#endif //!__MESSAGELIST_PANE_H
