@@ -14,10 +14,10 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
-#ifndef __MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H__
-#define __MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H__
+#ifndef MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H
+#define MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H
 
 namespace MessageList {
 namespace Core {
@@ -47,4 +47,4 @@ public:
 } // namespace Utils
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H__
+#endif //!__MESSAGELIST_UTILS_AGGREGATIONCOMBOBOX_P_H
