@@ -20,6 +20,7 @@
 #include "grantleeheaderformattertest.h"
 
 #include <MessageViewer/GrantleeHeaderStyle>
+#include <MimeTreeParser/NodeHelper>
 #include "../grantleeheaderformatter.h"
 
 #include <QFile>
@@ -102,6 +103,8 @@ void GrantleeHeaderFormatterTest::testInvalid()
 {
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     auto aMsg = readAndParseMail(QStringLiteral("allheaders.mbox"));
 
     QString filename = QStringLiteral("invalid");
@@ -117,6 +120,8 @@ void GrantleeHeaderFormatterTest::testPrint()
 
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     KMime::Message::Ptr aMsg(new KMime::Message);
 
     const QString &absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
@@ -132,6 +137,32 @@ void GrantleeHeaderFormatterTest::testPrint()
     }
 }
 
+void GrantleeHeaderFormatterTest::testFancyDate()
+{
+    QString tmplName = QStringLiteral("fancydate.tmpl");
+
+    auto style = GrantleeHeaderStyle();
+    auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
+    KMime::Message::Ptr msg(new KMime::Message);
+
+    {
+        auto datetime(QDateTime::currentDateTime());
+        datetime.setTime(QTime(12, 34, 56));
+        datetime = datetime.addDays(-1);
+
+        const QByteArray data = "From: from@example.com\nDate: " + datetime.toString(Qt::RFC2822Date).toLocal8Bit() + "\nTo: to@example.com\n\ncontent";
+        msg->setContent(KMime::CRLFtoLF(data));
+        msg->parse();
+    }
+
+    const QString &absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
+
+    const QString &data = formatter.toHtml(QStringList(), QStringLiteral(HEADER_DATA_DIR), tmplName, &style, msg.data(), false);
+    testHeaderFile(QStringLiteral("<div><div>")+data, absolutePath, QStringLiteral("fancydate"));
+}
+
 void GrantleeHeaderFormatterTest::testBlock_data()
 {
     QTest::addColumn<QString>("tmplName");
@@ -152,6 +183,8 @@ void GrantleeHeaderFormatterTest::testBlock()
 
     auto style = GrantleeHeaderStyle();
     auto formatter = GrantleeHeaderFormatter();
+    MimeTreeParser::NodeHelper nodeHelper;
+    style.setNodeHelper(&nodeHelper);
     auto aMsg = readAndParseMail(QStringLiteral("headertest.mbox"));
 
     QString absolutePath = QStringLiteral(HEADER_DATA_DIR) + QLatin1Char('/') + tmplName;
