@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 #ifndef GRANTLEEHEADERSTYLETEST_H
 #define GRANTLEEHEADERSTYLETEST_H
@@ -26,6 +26,10 @@ class GrantleeHeaderStyleTest : public QObject
 {
     Q_OBJECT
 
+public Q_SLOTS:
+    void initTestCase();
+    void cleanupTestCase();
+
 private Q_SLOTS:
     void testName();
     void testRenderHeaderNoMessage();
@@ -34,6 +38,9 @@ private Q_SLOTS:
     void testRenderHeaderVCard();
     void testRenderHeader_data();
     void testRenderHeader();
+
+private:
+    QString expectedDataLocation;
 };
 
 #endif
