@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,21 +24,20 @@
 
 namespace MessageViewer {
 class GrantleeHeaderStylePrivate;
+/**
+ * @brief The GrantleeHeaderStyle class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT GrantleeHeaderStyle : public HeaderStyle
 {
 public:
     GrantleeHeaderStyle();
-    ~GrantleeHeaderStyle();
+    ~GrantleeHeaderStyle() override;
 
 public:
     const char *name() const override;
 
-    QString format(KMime::Message *message) const override;
-
-    bool hasAttachmentQuickList() const override;
-
-    bool showMailAction() const;
-    void setShowMailAction(bool showAction);
+    Q_REQUIRED_RESULT QString format(KMime::Message *message) const override;
 private:
     GrantleeHeaderStylePrivate *const d;
 };
