@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,13 +24,11 @@ class MessageViewer::HeaderStylePluginPrivate
 {
 public:
     HeaderStylePluginPrivate()
-        : mIsEnabled(false)
-        , mShowEmoticons(true)
     {
     }
 
-    bool mIsEnabled;
-    bool mShowEmoticons;
+    bool mIsEnabled = false;
+    bool mShowEmoticons = true;
 };
 
 HeaderStylePlugin::HeaderStylePlugin(QObject *parent)
@@ -79,3 +77,21 @@ void HeaderStylePlugin::showConfigureDialog(QWidget *parent)
     Q_UNUSED(parent);
     //Reimplement
 }
+
+QString HeaderStylePlugin::extraScreenCss(const QString &headerFont) const
+{
+    Q_UNUSED(headerFont);
+    return {};
+}
+
+QString HeaderStylePlugin::extraPrintCss(const QString &headerFont) const
+{
+    Q_UNUSED(headerFont);
+    return {};
+}
+
+QString HeaderStylePlugin::extraCommonCss(const QString &headerFont) const
+{
+    Q_UNUSED(headerFont);
+    return {};
+}
