@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,12 +30,12 @@ public:
     ~WebEngineEmbedPart();
 
     void clear();
-    bool isEmpty() const;
+    Q_REQUIRED_RESULT bool isEmpty() const;
 
-    QMap<QString, QString> embeddedPartMap() const;
+    Q_REQUIRED_RESULT QMap<QString, QString> embeddedPartMap() const;
 
     void addEmbedPart(const QByteArray &contentId, const QString &contentURL);
-    QString contentUrl(const QString &contentId) const;
+    Q_REQUIRED_RESULT QString contentUrl(const QString &contentId) const;
 
     static WebEngineEmbedPart *self();
 private:
