@@ -39,7 +39,15 @@ void RenderTest::initTestCase()
 {
     Test::setupEnv();
 }
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    setenv("LC_ALL", "en_US.utf-8", 1);
+    setenv("TZ", "UTC", 1);
+}
 
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
 void RenderTest::testRenderSmart_data()
 {
     QTest::addColumn<QString>("mailFileName");
@@ -51,7 +59,7 @@ void RenderTest::testRenderSmart_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         if (!QFile::exists(dir.path() + QLatin1Char('/') + file + QStringLiteral(".html"))) {
             continue;
         }
@@ -79,7 +87,7 @@ void RenderTest::testRenderSmartAsync_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         if (!QFile::exists(dir.path() + QLatin1Char('/') + file
                            + QStringLiteral(".inProgress.html"))) {
             continue;
@@ -111,8 +119,8 @@ void RenderTest::testRenderSmartDetails_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
-        QString fname = dir.path() + QStringLiteral("/details/") + file + QStringLiteral(".html");
+    for (const QString &file : l) {
+        QString fname = dir.path() + QLatin1String("/details/") + file + QLatin1String(".html");
         if (!QFile::exists(fname)) {
             continue;
         }
@@ -138,10 +146,10 @@ void RenderTest::testRenderInlined_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
-        QString fname = dir.path() + QStringLiteral("/inlined/") + file + QStringLiteral(".html");
+    for (const QString &file : l) {
+        QString fname = dir.path() + QLatin1String("/inlined/") + file + QLatin1String(".html");
         if (!QFile::exists(fname)) {
-            fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
+            fname = dir.path() + QLatin1Char('/') + file + QLatin1String(".html");
             if (!QFile::exists(fname)) {
                 continue;
             }
@@ -169,10 +177,10 @@ void RenderTest::testRenderIconic_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
-        QString fname = dir.path() + QStringLiteral("/iconic/") + file + QStringLiteral(".html");
+    for (const QString &file : l) {
+        QString fname = dir.path() + QLatin1String("/iconic/") + file + QLatin1String(".html");
         if (!QFile::exists(fname)) {
-            fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
+            fname = dir.path() + QLatin1Char('/') + file + QLatin1String(".html");
             if (!QFile::exists(fname)) {
                 continue;
             }
@@ -200,10 +208,10 @@ void RenderTest::testRenderHidden_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
-        QString fname = dir.path() + QStringLiteral("/hidden/") + file + QStringLiteral(".html");
+    for (const QString &file : l) {
+        QString fname = dir.path() + QLatin1String("/hidden/") + file + QLatin1String(".html");
         if (!QFile::exists(fname)) {
-            fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
+            fname = dir.path() + QLatin1Char('/') + file + QLatin1String(".html");
             if (!QFile::exists(fname)) {
                 continue;
             }
@@ -231,11 +239,11 @@ void RenderTest::testRenderHeaderOnly_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
-        QString fname = dir.path() + QStringLiteral("/headeronly/") + file
+    for (const QString &file : l) {
+        QString fname = dir.path() + QLatin1String("/headeronly/") + file
                         + QStringLiteral(".html");
         if (!QFile::exists(fname)) {
-            fname = dir.path() + QStringLiteral("/") + file + QStringLiteral(".html");
+            fname = dir.path() + QLatin1Char('/') + file + QLatin1String(".html");
             if (!QFile::exists(fname)) {
                 continue;
             }
@@ -259,7 +267,7 @@ QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QS
                                           QString::fromUtf8(messagePart->metaObject()->className()));
     QString ret = line;
 
-    indent += QStringLiteral(" ");
+    indent += QLatin1Char(' ');
     foreach (const auto &subPart, messagePart->subParts()) {
         ret += renderTreeHelper(subPart, indent);
     }
@@ -325,11 +333,11 @@ void RenderTest::testRender()
     connect(&nodeHelper, &MimeTreeParser::NodeHelper::update, &loop, &QEventLoop::quit);
     otp.setAllowAsync(bAsync);
 
-    fileWriter.begin();
-    fileWriter.write(cssHelper.htmlHead(false));
-
     otp.parseObjectTree(msg.data());
 
+    fileWriter.begin();
+    fileWriter.write(cssHelper.htmlHead(false));
+    testSource.render(otp.parsedPart(), false);
     fileWriter.write(QStringLiteral("</body></html>"));
     fileWriter.end();
 
@@ -342,11 +350,11 @@ void RenderTest::testRender()
         MimeTreeParser::ObjectTreeParser otp(&testSource, &nodeHelper);
         otp.setAllowAsync(bAsync);
 
-        fileWriter.begin();
-        fileWriter.write(cssHelper.htmlHead(false));
-
         otp.parseObjectTree(msg.data());
 
+        fileWriter.begin();
+        fileWriter.write(cssHelper.htmlHead(false));
+        testSource.render(otp.parsedPart(), false);
         fileWriter.write(QStringLiteral("</body></html>"));
         fileWriter.end();
 
