@@ -15,11 +15,11 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef __MESSAGEVIEWER_TEST_SHOWONLYMIMEPARTTEST_H__
-#define __MESSAGEVIEWER_TEST_SHOWONLYMIMEPARTTEST_H__
+#ifndef MESSAGEVIEWER_TEST_SHOWONLYMIMEPARTTEST_H
+#define MESSAGEVIEWER_TEST_SHOWONLYMIMEPARTTEST_H
 
 #include <QObject>
 
