@@ -17,21 +17,21 @@
     02110-1301, USA.
 */
 
-#ifndef __MESSSAGEVIEWER_TESTCSSHELPER_H__
-#define __MESSSAGEVIEWER_TESTCSSHELPER_H__
+#ifndef MESSSAGEVIEWER_TESTCSSHELPER_H
+#define MESSSAGEVIEWER_TESTCSSHELPER_H
 
-#include <MessageViewer/CSSHelperBase>
+#include <MessageViewer/CSSHelper>
 
 namespace MessageViewer {
 namespace Test {
-class TestCSSHelper : public MessageViewer::CSSHelperBase
+class TestCSSHelper : public MessageViewer::CSSHelper
 {
 public:
     explicit TestCSSHelper(const QPaintDevice *pd);
-    virtual ~TestCSSHelper();
+    ~TestCSSHelper() override;
     QString htmlHead(bool fixed) const override;
 };
 }
 }
 
-#endif // __MESSSAGEVIEWER_TESTCSSHELPER_H__
+#endif // MESSSAGEVIEWER_TESTCSSHELPER_H
