@@ -18,8 +18,8 @@
   02110-1301, USA.
 */
 
-#ifndef MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSSAGE_H
-#define MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSSAGE_H
+#ifndef MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSAGETEST_H
+#define MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSAGETEST_H
 
 #include <QObject>
 
@@ -28,19 +28,9 @@ class UnencryptedMessageTest : public QObject
     Q_OBJECT
 private Q_SLOTS:
     void initTestCase();
-    void testMailWithoutEncryption();
-    void testSMIMESignedEncrypted();
-    void testOpenPGPSignedEncrypted();
-    void testOpenPGPEncryptedAndSigned();
-    void testForwardedOpenPGPSignedEncrypted();
-    void testSignedForwardedOpenPGPSignedEncrypted();
-    void testOpenPGPEncrypted();
-    void testOpenPGPEncryptedNotDecrypted();
-    void testAsync_data();
-    void testAsync();
     void testNotDecrypted_data();
     void testNotDecrypted();
     void testSMimeAutoCertImport();
 };
 
-#endif //__MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSSAGE_H
+#endif // MESSAGEVIEWER_TESTS_UNENCRYPTEDMESSAGETEST_H
