@@ -21,13 +21,14 @@
 
 #include "defaultrenderer_p.h"
 
+#include "utils/messageviewerutil.h"
+
 #include "messageviewer_debug.h"
 
 #include "converthtmltoplaintext.h"
 #include "messagepartrendererbase.h"
 #include "messagepartrendererfactory.h"
 #include "htmlblock.h"
-
 #include "utils/iconnamecache.h"
 #include "utils/mimetype.h"
 #include "viewer/attachmentstrategy.h"
@@ -37,7 +38,6 @@
 #include "htmlwriter/bufferedhtmlwriter.h"
 #include <MimeTreeParser/MessagePart>
 #include <MimeTreeParser/ObjectTreeParser>
-#include <GrantleeTheme/QtResourceTemplateLoader>
 
 #include <QGpgME/Protocol>
 
@@ -46,8 +46,8 @@
 #include <KEmailAddress>
 #include <KIconLoader>
 #include <KLocalizedString>
+#include <QRegularExpression>
 
-#include <QApplication>
 #include <QUrl>
 
 #include <grantlee/context.h>
@@ -56,6 +56,8 @@
 #include <grantlee/templateloader.h>
 #include <grantlee/template.h>
 
+#include <qtwebenginewidgetsversion.h>
+
 using namespace MimeTreeParser;
 using namespace MessageViewer;
 
@@ -240,54 +242,6 @@ QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code, G
     return result;
 }
 
-/** Checks whether @p str contains external references. To be precise,
-    we only check whether @p str contains 'xxx="http[s]:' where xxx is
-    not href. Obfuscated external references are ignored on purpose.
-*/
-
-bool containsExternalReferences(const QString &str, const QString &extraHead)
-{
-    const bool hasBaseInHeader = extraHead.contains(QLatin1String(
-                                                        "<base href=\""), Qt::CaseInsensitive);
-    if (hasBaseInHeader && (str.contains(QLatin1String("href=\"/"), Qt::CaseInsensitive)
-                            || str.contains(QLatin1String("<img src=\"/"), Qt::CaseInsensitive))) {
-        return true;
-    }
-    int httpPos = str.indexOf(QLatin1String("\"http:"), Qt::CaseInsensitive);
-    int httpsPos = str.indexOf(QLatin1String("\"https:"), Qt::CaseInsensitive);
-
-    while (httpPos >= 0 || httpsPos >= 0) {
-        // pos = index of next occurrence of "http: or "https: whichever comes first
-        int pos = (httpPos < httpsPos)
-                  ? ((httpPos >= 0) ? httpPos : httpsPos)
-                  : ((httpsPos >= 0) ? httpsPos : httpPos);
-        // look backwards for "href"
-        if (pos > 5) {
-            int hrefPos = str.lastIndexOf(QLatin1String("href"), pos - 5, Qt::CaseInsensitive);
-            // if no 'href' is found or the distance between 'href' and '"http[s]:'
-            // is larger than 7 (7 is the distance in 'href = "http[s]:') then
-            // we assume that we have found an external reference
-            if ((hrefPos == -1) || (pos - hrefPos > 7)) {
-                // HTML messages created by KMail itself for now contain the following:
-                // <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-                // Make sure not to show an external references warning for this string
-                int dtdPos = str.indexOf(QLatin1String(
-                                             "http://www.w3.org/TR/html4/loose.dtd"), pos + 1);
-                if (dtdPos != (pos + 1)) {
-                    return true;
-                }
-            }
-        }
-        // find next occurrence of "http: or "https:
-        if (pos == httpPos) {
-            httpPos = str.indexOf(QLatin1String("\"http:"), httpPos + 6, Qt::CaseInsensitive);
-        } else {
-            httpsPos = str.indexOf(QLatin1String("\"https:"), httpsPos + 7, Qt::CaseInsensitive);
-        }
-    }
-    return false;
-}
-
 // FIXME this used to go through the full webkit parser to extract the body and head blocks
 // until we have that back, at least attempt to fix some of the damage
 // yes, "parsing" HTML with regexps is very very wrong, but it's still better than not filtering
@@ -295,11 +249,11 @@ bool containsExternalReferences(const QString &str, const QString &extraHead)
 QString processHtml(const QString &htmlSource, QString &extraHead)
 {
     QString s = htmlSource.trimmed();
-    s = s.replace(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
-    s = s.replace(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive)).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive)).trimmed();
 
     // head
-    s = s.replace(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive)).trimmed();
     const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
     if (startIndex >= 0) {
         const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
@@ -307,14 +261,22 @@ QString processHtml(const QString &htmlSource, QString &extraHead)
         if (endIndex < 0) {
             return htmlSource;
         }
-        extraHead = s.mid(startIndex + 6 , endIndex - startIndex - 6);
+        extraHead = s.mid(startIndex + 6, endIndex - startIndex - 6);
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
+        //Remove this hack with https://codereview.qt-project.org/#/c/256100/2 is merged
+        //Don't authorize to refresh content.
+        if (MessageViewer::Util::excludeExtraHeader(s)) {
+            extraHead.clear();
+        }
+#endif
+
         s = s.mid(endIndex + 7).trimmed();
     }
 
     // body
-    s = s.replace(QRegExp(QStringLiteral("<body[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
-    s = s.replace(QRegExp(QStringLiteral("</html>$"), Qt::CaseInsensitive), QString()).trimmed();
-    s = s.replace(QRegExp(QStringLiteral("</body>$"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("<body[^>]*>"), Qt::CaseInsensitive)).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("</html>$"), Qt::CaseInsensitive)).trimmed();
+    s = s.remove(QRegExp(QStringLiteral("</body>$"), Qt::CaseInsensitive)).trimmed();
     return s;
 }
 
@@ -340,7 +302,7 @@ Interface::ObjectTreeSource *DefaultRendererPrivate::source() const
 
 void DefaultRendererPrivate::renderSubParts(const MessagePart::Ptr &msgPart, HtmlWriter *htmlWriter)
 {
-    foreach (const auto &m, msgPart->subParts()) {
+    for (const auto &m : msgPart->subParts()) {
         renderFactory(m, htmlWriter);
     }
 }
@@ -380,7 +342,7 @@ void DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp
     if (!mp->hasSubParts()) {
         return;
     }
-    Grantlee::Template t = MessagePartRendererManager::self()->loadByName(QStringLiteral(":/encapsulatedrfc822messagepart.html"));
+    Grantlee::Template t = MessagePartRendererManager::self()->loadByName(QStringLiteral("encapsulatedrfc822messagepart.html"));
     Grantlee::Context c = MessagePartRendererManager::self()->createContext();
     QObject block;
 
@@ -404,7 +366,7 @@ void DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp
 void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
-                                                                                             ":/htmlmessagepart.html"));
+                                                                                             "htmlmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
     QObject block;
 
@@ -426,7 +388,7 @@ void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *
         }
 
         block.setProperty("containsExternalReferences",
-                          containsExternalReferences(bodyText, extraHead));
+                          Util::containsExternalReferences(bodyText, extraHead));
         c.insert(QStringLiteral("content"), bodyText);
     }
 
@@ -453,7 +415,7 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
     const auto metaData = *mp->partMetaData();
 
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
-                                                                                             ":/encryptedmessagepart.html"));
+                                                                                             "encryptedmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
     QObject block;
 
@@ -479,6 +441,7 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
     c.insert(QStringLiteral("block"), &block);
 
     block.setProperty("isPrinting", isPrinting());
+    block.setProperty("detailHeader", showEncryptionDetails());
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("isDecrypted", mp->decryptMessage());
     block.setProperty("isDecryptable", metaData.isDecryptable);
@@ -502,7 +465,7 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
     const bool isSMIME = cryptoProto && (cryptoProto == QGpgME::smime());
 
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
-                                                                                             ":/signedmessagepart.html"));
+                                                                                             "signedmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
     QObject block;
 
@@ -566,7 +529,7 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
                                                                                     "0x")
                                                                                 + metaData.keyId)));
         } else {
-            keyWithWithoutURL = QStringLiteral("0x") + QString::fromUtf8(metaData.keyId);
+            keyWithWithoutURL = QLatin1String("0x") + QString::fromUtf8(metaData.keyId);
         }
         block.setProperty("keyWithWithoutURL", keyWithWithoutURL);
     }
@@ -791,7 +754,7 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
 
     auto mode = mp->preferredMode();
     if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
-        foreach (const auto m, mp->availableModes()) {
+        for (const auto m : mp->availableModes()) {
             if (m != MimeTreeParser::Util::MultipartPlain) {
                 mode = m;
                 break;
@@ -810,7 +773,7 @@ void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *
 {
     const GpgME::ImportResult &importResult(mp->importResult());
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
-                                                                                             ":/certmessagepart.html"));
+                                                                                             "certmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
     QObject block;
 
@@ -872,48 +835,48 @@ void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, Html
         return;
     }
 
-    if (className == QStringLiteral("MimeTreeParser::MessagePartList")) {
+    if (className == QLatin1String("MimeTreeParser::MessagePartList")) {
         auto mp = msgPart.dynamicCast<MessagePartList>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::MimeMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::MimeMessagePart")) {
         auto mp = msgPart.dynamicCast<MimeMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::EncapsulatedRfc822MessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::EncapsulatedRfc822MessagePart")) {
         auto mp = msgPart.dynamicCast<EncapsulatedRfc822MessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::HtmlMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::HtmlMessagePart")) {
         auto mp = msgPart.dynamicCast<HtmlMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::SignedMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::SignedMessagePart")) {
         auto mp = msgPart.dynamicCast<SignedMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::EncryptedMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::EncryptedMessagePart")) {
         auto mp = msgPart.dynamicCast<EncryptedMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::AlternativeMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::AlternativeMessagePart")) {
         auto mp = msgPart.dynamicCast<AlternativeMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
-    } else if (className == QStringLiteral("MimeTreeParser::CertMessagePart")) {
+    } else if (className == QLatin1String("MimeTreeParser::CertMessagePart")) {
         auto mp = msgPart.dynamicCast<CertMessagePart>();
         if (mp) {
             render(mp, htmlWriter);
         }
     } else {
-        qCWarning(MESSAGEVIEWER_LOG) << "We got a unkonwn classname, using default behaviour for "
+        qCWarning(MESSAGEVIEWER_LOG) << "We got a unknown classname, using default behaviour for "
                                      << className;
     }
 }
@@ -1071,6 +1034,11 @@ bool DefaultRendererPrivate::showSignatureDetails() const
     return mShowSignatureDetails;
 }
 
+bool DefaultRendererPrivate::showEncryptionDetails() const
+{
+    return mShowEncryptionDetails;
+}
+
 int DefaultRendererPrivate::levelQuote() const
 {
     return mLevelQuote;
@@ -1111,6 +1079,11 @@ void DefaultRenderer::setShowExpandQuotesMark(bool showExpandQuotesMark)
     d->mShowExpandQuotesMark = showExpandQuotesMark;
 }
 
+void DefaultRenderer::setShowEncryptionDetails(bool showEncryptionDetails)
+{
+    d->mShowEncryptionDetails = showEncryptionDetails;
+}
+
 void DefaultRenderer::setShowSignatureDetails(bool showSignatureDetails)
 {
     d->mShowSignatureDetails = showSignatureDetails;
@@ -1126,20 +1099,18 @@ void DefaultRenderer::setHtmlLoadExternal(bool htmlLoadExternal)
     d->mHtmlLoadExternal = htmlLoadExternal;
 }
 
-void DefaultRenderer::setCreateMessageHeader(std::function<QString(KMime::Message *)> createMessageHeader)
+void DefaultRenderer::setCreateMessageHeader(const std::function<QString(KMime::Message *)> &createMessageHeader)
 {
     d->mCreateMessageHeader = createMessageHeader;
 }
 
 QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QString indent)
 {
-    const QString line
+    QString ret
         = QStringLiteral("%1 * %3\n").arg(indent,
                                           QString::fromUtf8(messagePart->metaObject()->className()));
-    QString ret = line;
-
-    indent += QStringLiteral(" ");
-    foreach (const auto &subPart, messagePart->subParts()) {
+    indent += QLatin1Char(' ');
+    for (const auto &subPart : messagePart->subParts()) {
         ret += renderTreeHelper(subPart, indent);
     }
     return ret;
