@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -86,8 +86,8 @@ void ScamDetectionDetailsDialog::slotSaveAs()
             QTextStream ts(&file);
             ts.setCodec("UTF-8");
             QString htmlStr = mDetails->toHtml();
-            htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""),
-                            QStringLiteral(
+            htmlStr.replace(QLatin1String("meta name=\"qrichtext\" content=\"1\""),
+                            QLatin1String(
                                 "meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
             ts <<  htmlStr;
             file.close();
