@@ -19,8 +19,8 @@
     02110-1301, USA.
 */
 
-#ifndef MESSAGEVIEWER_MESSAGEREADHANDLER_H
-#define MESSAGEVIEWER_MESSAGEREADHANDLER_H
+#ifndef MESSAGEVIEWER_MARKMESSAGEREADHANDLER_H
+#define MESSAGEVIEWER_MARKMESSAGEREADHANDLER_H
 
 #include "messageviewer_export.h"
 
