@@ -5,8 +5,9 @@
     Copyright (c) 2003 Marc Mutz <mutz@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
     KMail is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,12 +37,15 @@
 
 #include <QColor>
 #include <QFont>
-#include <QUrl>
 
 class QString;
 class QPaintDevice;
 
 namespace MessageViewer {
+class HeaderStylePlugin;
+/**
+ * @brief The CSSHelperBase class
+ */
 class MESSAGEVIEWER_EXPORT CSSHelperBase
 {
 public:
@@ -79,6 +83,21 @@ public:
 
     Q_REQUIRED_RESULT QString addEndBlockQuote(int numberBlock) const;
     Q_REQUIRED_RESULT QString addStartBlockQuote(int numberBlock) const;
+
+    Q_REQUIRED_RESULT QString extraScreenCss(const QString &headerFont) const;
+    Q_REQUIRED_RESULT QString extraPrintCss(const QString &headerFont) const;
+    Q_REQUIRED_RESULT QString extraCommonCss(const QString &headerFont) const;
+
+    void setHeaderPlugin(const HeaderStylePlugin *headerPlugin);
+
+    enum InlineMessageType {
+        Positive,
+        Information,
+        Warning,
+        Error,
+        MESSAGE_TYPE_COUNT
+    };
+
 protected:
     /** Recalculate PGP frame and body colors (should be called after changing
         color settings) */
@@ -93,6 +112,7 @@ protected:
     QColor mQuoteColor[3];
     bool mRecycleQuoteColors;
     bool mShrinkQuotes;
+    bool mUseBrowserColor = false;
     QColor mForegroundColor;
     QColor mLinkColor;
     QColor mBackgroundColor;
@@ -117,8 +137,9 @@ protected:
     QColor cPgpEncrH;
     QColor cPgpEncrHT;
     QColor cPgpEncrB;
-    // color of frame of warning preceding the source of HTML messages
-    QColor cHtmlWarning;
+
+    // colors for inline message boxes, see KMessageWidget or Kirigami::InlineMessage
+    QColor cInlineMessage[MESSAGE_TYPE_COUNT];
 
     QString imgShowUrl;
     QString imgHideUrl;
@@ -133,9 +154,12 @@ private:
     // returns CSS rules common to both screen and print media types
     QString commonCssDefinitions() const;
     QString fullAddressList() const;
+    QString linkColorDefinition() const;
+    QString defaultScreenHeaderFont() const;
+    QString defaultPrintHeaderFont() const;
 
-private:
     const QPaintDevice *mPaintDevice = nullptr;
+    const HeaderStylePlugin *mHeaderPlugin = nullptr;
 };
 }
 
