@@ -7,8 +7,9 @@
     Copyright (c) 2009 Andras Mantia <andras@kdab.net>
 
     KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
     KMail is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,8 +33,8 @@
 */
 
 #include "urlhandlermanager.h"
+#include "urlhandlermanager_p.h"
 #include "messageviewer_debug.h"
-#include "messageviewer/urlhandler.h"
 #include "interfaces/bodyparturlhandler.h"
 #include "utils/mimetype.h"
 #include "viewer/viewer_p.h"
@@ -52,6 +53,8 @@
 
 #include <KMime/Content>
 #include <KEmailAddress>
+#include <kmbox/mbox.h>
+#include "messageflags.h"
 
 #include <KRun>
 #include <KIconLoader>
@@ -69,6 +72,7 @@
 #include <QMimeDatabase>
 #include <QStandardPaths>
 #include <QUrl>
+#include <QUrlQuery>
 
 #include <algorithm>
 
@@ -82,285 +86,13 @@ using namespace MessageCore;
 
 URLHandlerManager *URLHandlerManager::self = nullptr;
 
-namespace {
-class KMailProtocolURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    KMailProtocolURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~KMailProtocolURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *) const override
-    {
-        return url.scheme() == QLatin1String("kmail");
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-};
-
-class ExpandCollapseQuoteURLManager : public MimeTreeParser::URLHandler
-{
-public:
-    ExpandCollapseQuoteURLManager() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~ExpandCollapseQuoteURLManager()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-};
-
-class SMimeURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    SMimeURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~SMimeURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-};
-
-class MailToURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    MailToURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~MailToURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-};
-
-class ContactUidURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    ContactUidURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~ContactUidURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-};
-
-class HtmlAnchorHandler : public MimeTreeParser::URLHandler
-{
-public:
-    HtmlAnchorHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~HtmlAnchorHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
-    {
-        return QString();
-    }
-};
-
-class AttachmentURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    AttachmentURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~AttachmentURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleShiftClick(const QUrl &, ViewerPrivate *window) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-private:
-    KMime::Content *nodeForUrl(const QUrl &url, ViewerPrivate *w) const;
-    bool attachmentIsInHeader(const QUrl &url) const;
-};
-
-class ShowAuditLogURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    ShowAuditLogURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~ShowAuditLogURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-};
-
-// Handler that prevents dragging of internal images added by KMail, such as the envelope image
-// in the enterprise header
-class InternalImageURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    InternalImageURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~InternalImageURLHandler()
-    {
-    }
-
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
-    {
-        return QString();
-    }
-};
-
-class EmbeddedImageURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    EmbeddedImageURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~EmbeddedImageURLHandler()
-    {
-    }
-
-    bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
-    bool handleClick(const QUrl &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &url, ViewerPrivate *) const override
-    {
-        Q_UNUSED(url);
-        return QString();
-    }
-};
-
-class KRunURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    KRunURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~KRunURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
-    {
-        return false;
-    }
-
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
-    {
-        return QString();
-    }
-};
-} // anon namespace
-
 //
 //
 // BodyPartURLHandlerManager
 //
 //
 
-class URLHandlerManager::BodyPartURLHandlerManager : public MimeTreeParser::URLHandler
-{
-public:
-    BodyPartURLHandlerManager() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~BodyPartURLHandlerManager();
-
-    bool handleClick(const QUrl &, ViewerPrivate *) const override;
-    bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
-    QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
-
-    void registerHandler(const Interface::BodyPartURLHandler *handler, const QString &mimeType);
-    void unregisterHandler(const Interface::BodyPartURLHandler *handler);
-
-private:
-    QVector<const Interface::BodyPartURLHandler *> handlersForPart(KMime::Content *node) const;
-
-    typedef QHash<QByteArray, QVector<const Interface::BodyPartURLHandler *> > BodyPartHandlerList;
-    BodyPartHandlerList mHandlers;
-};
-
-URLHandlerManager::BodyPartURLHandlerManager::~BodyPartURLHandlerManager()
+BodyPartURLHandlerManager::~BodyPartURLHandlerManager()
 {
     for_each(mHandlers.begin(), mHandlers.end(),
              [](QVector<const Interface::BodyPartURLHandler *> &handlers) {
@@ -369,7 +101,7 @@ URLHandlerManager::BodyPartURLHandlerManager::~BodyPartURLHandlerManager()
     });
 }
 
-void URLHandlerManager::BodyPartURLHandlerManager::registerHandler(
+void BodyPartURLHandlerManager::registerHandler(
     const Interface::BodyPartURLHandler *handler, const QString &mimeType)
 {
     if (!handler) {
@@ -384,7 +116,7 @@ void URLHandlerManager::BodyPartURLHandlerManager::registerHandler(
     it->push_back(handler);
 }
 
-void URLHandlerManager::BodyPartURLHandlerManager::unregisterHandler(
+void BodyPartURLHandlerManager::unregisterHandler(
     const Interface::BodyPartURLHandler *handler)
 {
     // don't delete them, only remove them from the list!
@@ -411,7 +143,7 @@ static KMime::Content *partNodeFromXKMailUrl(const QUrl &url, ViewerPrivate *w,
     // urlPath format is: /bodypart/<random number>/<part id>/<path>
 
     qCDebug(MESSAGEVIEWER_LOG) << "BodyPartURLHandler: urlPath ==" << urlPath;
-    if (!urlPath.startsWith(QStringLiteral("/bodypart/"))) {
+    if (!urlPath.startsWith(QLatin1String("/bodypart/"))) {
         return nullptr;
     }
 
@@ -428,11 +160,15 @@ static KMime::Content *partNodeFromXKMailUrl(const QUrl &url, ViewerPrivate *w,
     return w->nodeFromUrl(QUrl(urlParts.at(1)));
 }
 
-QVector<const Interface::BodyPartURLHandler *> URLHandlerManager::BodyPartURLHandlerManager::handlersForPart(KMime::Content *node) const
+QVector<const Interface::BodyPartURLHandler *> BodyPartURLHandlerManager::handlersForPart(KMime::Content *node) const
 {
     if (auto ct = node->contentType(false)) {
-        const auto mimeType = ct->mimeType();
+        auto mimeType = ct->mimeType();
         if (!mimeType.isEmpty()) {
+            // Bug 390900
+            if (mimeType == "text/x-vcard") {
+                mimeType = "text/vcard";
+            }
             return mHandlers.value(mimeType);
         }
     }
@@ -440,7 +176,7 @@ QVector<const Interface::BodyPartURLHandler *> URLHandlerManager::BodyPartURLHan
     return {};
 }
 
-bool URLHandlerManager::BodyPartURLHandlerManager::handleClick(const QUrl &url, ViewerPrivate *w) const
+bool BodyPartURLHandlerManager::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -462,7 +198,7 @@ bool URLHandlerManager::BodyPartURLHandlerManager::handleClick(const QUrl &url,
     return false;
 }
 
-bool URLHandlerManager::BodyPartURLHandlerManager::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
+bool BodyPartURLHandlerManager::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -483,7 +219,7 @@ bool URLHandlerManager::BodyPartURLHandlerManager::handleContextMenuRequest(cons
     return false;
 }
 
-QString URLHandlerManager::BodyPartURLHandlerManager::statusBarMessage(const QUrl &url, ViewerPrivate *w) const
+QString BodyPartURLHandlerManager::statusBarMessage(const QUrl &url, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -524,7 +260,6 @@ URLHandlerManager::URLHandlerManager()
     registerHandler(new ShowAuditLogURLHandler());
     registerHandler(new InternalImageURLHandler);
     registerHandler(new KRunURLHandler());
-    //registerHandler(new EmbeddedImageURLHandler());
 }
 
 URLHandlerManager::~URLHandlerManager()
@@ -644,7 +379,6 @@ QString URLHandlerManager::statusBarMessage(const QUrl &url, ViewerPrivate *w) c
 //
 //
 
-namespace {
 bool KMailProtocolURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     if (url.scheme() == QLatin1String("kmail")) {
@@ -679,28 +413,12 @@ bool KMailProtocolURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) con
             w->update(MimeTreeParser::Force);
             return true;
         } else if (urlPath == QLatin1String("showEncryptionDetails")) {
-            w->setHideEncryptionDetails(false);
+            w->setShowEncryptionDetails(true);
+            w->update(MimeTreeParser::Force);
             return true;
         } else if (urlPath == QLatin1String("hideEncryptionDetails")) {
-            w->setHideEncryptionDetails(true);
-            return true;
-        } else if (urlPath == QLatin1String("showAttachmentQuicklist")) {
-            w->setShowAttachmentQuicklist(false);
-            return true;
-        } else if (urlPath == QLatin1String("hideAttachmentQuicklist")) {
-            w->setShowAttachmentQuicklist(true);
-            return true;
-        } else if (urlPath == QLatin1String("showFullToAddressList")) {
-            w->setFullToAddressList(false);
-            return true;
-        } else if (urlPath == QLatin1String("hideFullToAddressList")) {
-            w->setFullToAddressList(true);
-            return true;
-        } else if (urlPath == QLatin1String("showFullCcAddressList")) {
-            w->setFullCcAddressList(false);
-            return true;
-        } else if (urlPath == QLatin1String("hideFullCcAddressList")) {
-            w->setFullCcAddressList(true);
+            w->setShowEncryptionDetails(false);
+            w->update(MimeTreeParser::Force);
             return true;
         }
     }
@@ -709,7 +427,8 @@ bool KMailProtocolURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) con
 
 QString KMailProtocolURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) const
 {
-    if (url.scheme() == QLatin1String("kmail")) {
+    const QString schemeStr = url.scheme();
+    if (schemeStr == QLatin1String("kmail")) {
         const QString urlPath(url.path());
         if (urlPath == QLatin1String("showHTML")) {
             return i18n("Turn on HTML rendering for this message.");
@@ -729,29 +448,15 @@ QString KMailProtocolURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate
             return i18n("Show encryption details.");
         } else if (urlPath == QLatin1String("hideEncryptionDetails")) {
             return i18n("Hide encryption details.");
-        } else if (urlPath == QLatin1String("showAttachmentQuicklist")) {
-            return i18n("Hide attachment list.");
-        } else if (urlPath == QLatin1String("hideAttachmentQuicklist")) {
-            return i18n("Show attachment list.");
-        } else if (urlPath == QLatin1String("showFullToAddressList")) {
-            return i18n("Hide full \"To\" list");
-        } else if (urlPath == QLatin1String("hideFullToAddressList")) {
-            return i18n("Show full \"To\" list");
-        } else if (urlPath == QLatin1String("showFullCcAddressList")) {
-            return i18n("Hide full \"Cc\" list");
-        } else if (urlPath == QLatin1String("hideFullCcAddressList")) {
-            return i18n("Show full \"Cc\" list");
         } else {
             return QString();
         }
-    } else if (url.scheme() == QLatin1String("help")) {
+    } else if (schemeStr == QLatin1String("help")) {
         return i18n("Open Documentation");
     }
     return QString();
 }
-}
 
-namespace {
 bool ExpandCollapseQuoteURLManager::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     //  kmail:levelquote/?num      -> the level quote to collapse.
@@ -789,7 +494,6 @@ QString ExpandCollapseQuoteURLManager::statusBarMessage(const QUrl &url, ViewerP
     }
     return QString();
 }
-}
 
 bool foundSMIMEData(const QString &aUrl, QString &displayName, QString &libName, QString &keyId)
 {
@@ -828,7 +532,6 @@ bool foundSMIMEData(const QString &aUrl, QString &displayName, QString &libName,
     return !keyId.isEmpty();
 }
 
-namespace {
 bool SMimeURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     if (!url.hasFragment()) {
@@ -842,7 +545,7 @@ bool SMimeURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
     }
     QStringList lst;
     lst << QStringLiteral("--parent-windowid")
-        << QString::number((qlonglong)w->viewer()->mainWindow()->winId())
+        << QString::number(static_cast<qlonglong>(w->viewer()->mainWindow()->winId()))
         << QStringLiteral("--query") << keyId;
     if (!QProcess::startDetached(QStringLiteral("kleopatra"), lst)) {
         KMessageBox::error(w->mMainWindow, i18n("Could not start certificate manager. "
@@ -862,9 +565,7 @@ QString SMimeURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) cons
     }
     return i18n("Show certificate 0x%1", keyId);
 }
-}
 
-namespace {
 bool HtmlAnchorHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     if (!url.host().isEmpty() || !url.hasFragment()) {
@@ -874,9 +575,7 @@ bool HtmlAnchorHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
     w->scrollToAnchor(url.fragment());
     return true;
 }
-}
 
-namespace {
 QString MailToURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) const
 {
     if (url.scheme() == QLatin1String("mailto")) {
@@ -884,9 +583,7 @@ QString MailToURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) con
     }
     return QString();
 }
-}
 
-namespace {
 static QString searchFullEmailByUid(const QString &uid)
 {
     QString fullEmail;
@@ -925,17 +622,17 @@ bool ContactUidURLHandler::handleContextMenuRequest(const QUrl &url, const QPoin
         return false;
     }
 
-    QMenu *menu = new QMenu();
+    QMenu menu;
     QAction *open
-        = menu->addAction(QIcon::fromTheme(QStringLiteral("view-pim-contacts")),
-                          i18n("&Open in Address Book"));
+        = menu.addAction(QIcon::fromTheme(QStringLiteral("view-pim-contacts")),
+                         i18n("&Open in Address Book"));
 #ifndef QT_NO_CLIPBOARD
     QAction *copy
-        = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
-                          i18n("&Copy Email Address"));
+        = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
+                         i18n("&Copy Email Address"));
 #endif
 
-    QAction *a = menu->exec(p);
+    QAction *a = menu.exec(p);
     if (a == open) {
         runKAddressBook(url);
 #ifndef QT_NO_CLIPBOARD
@@ -949,7 +646,6 @@ bool ContactUidURLHandler::handleContextMenuRequest(const QUrl &url, const QPoin
         }
 #endif
     }
-    delete menu;
 
     return true;
 }
@@ -962,9 +658,7 @@ QString ContactUidURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *)
         return QString();
     }
 }
-}
 
-namespace {
 KMime::Content *AttachmentURLHandler::nodeForUrl(const QUrl &url, ViewerPrivate *w) const
 {
     if (!w || !w->mMessage) {
@@ -999,9 +693,9 @@ bool AttachmentURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
     if (inHeader) {
         w->scrollToAttachment(node);
     }
-    if (shouldShowDialog || w->nodeHelper()->isNodeDisplayedHidden(node)) {
-        w->openAttachment(node, w->nodeHelper()->tempFileUrlFromNode(node));
-    }
+    //if (shouldShowDialog || w->nodeHelper()->isNodeDisplayedHidden(node)) {
+    w->openAttachment(node, w->nodeHelper()->tempFileUrlFromNode(node));
+    //}
 
     return true;
 }
@@ -1015,9 +709,28 @@ bool AttachmentURLHandler::handleShiftClick(const QUrl &url, ViewerPrivate *wind
     if (!window) {
         return false;
     }
-    QUrl currentUrl;
-    if (Util::saveContents(window->viewer(), KMime::Content::List() << node, currentUrl)) {
-        window->viewer()->showOpenAttachmentFolderWidget(currentUrl);
+    if (node->contentType()->mimeType() == "text/x-moz-deleted") {
+        return false;
+    }
+
+    const bool isEncapsulatedMessage = node->parent() && node->parent()->bodyIsMessage();
+    if (isEncapsulatedMessage) {
+        KMime::Message::Ptr message(new KMime::Message);
+        message->setContent(node->parent()->bodyAsMessage()->encodedContent());
+        message->parse();
+        Akonadi::Item item;
+        item.setPayload<KMime::Message::Ptr>(message);
+        Akonadi::MessageFlags::copyMessageFlags(*message, item);
+        item.setMimeType(KMime::Message::mimeType());
+        QUrl url;
+        if (MessageViewer::Util::saveMessageInMboxAndGetUrl(url, Akonadi::Item::List() << item, window->viewer())) {
+            window->viewer()->showOpenAttachmentFolderWidget(QList<QUrl>() << url);
+        }
+    } else {
+        QList<QUrl> urlList;
+        if (Util::saveContents(window->viewer(), KMime::Content::List() << node, urlList)) {
+            window->viewer()->showOpenAttachmentFolderWidget(urlList);
+        }
     }
 
     return true;
@@ -1035,15 +748,49 @@ bool AttachmentURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) co
     if (!node) {
         return false;
     }
-    if (node->header<KMime::Headers::Subject>()) {
-        if (!node->contents().isEmpty()) {
-            node = node->contents().constFirst();
-            window->nodeHelper()->writeNodeToTempFile(node);
+    if (node->contentType()->mimeType() == "text/x-moz-deleted") {
+        return false;
+    }
+    QString fileName;
+    QUrl tUrl;
+    const bool isEncapsulatedMessage = node->parent() && node->parent()->bodyIsMessage();
+    if (isEncapsulatedMessage) {
+        KMime::Message::Ptr message(new KMime::Message);
+        message->setContent(node->parent()->bodyAsMessage()->encodedContent());
+        message->parse();
+        Akonadi::Item item;
+        item.setPayload<KMime::Message::Ptr>(message);
+        Akonadi::MessageFlags::copyMessageFlags(*message, item);
+        item.setMimeType(KMime::Message::mimeType());
+        fileName = window->nodeHelper()->writeFileToTempFile(node, Util::generateMboxFileName(item));
+
+        KMBox::MBox mbox;
+        QFile::remove(fileName);
+
+        if (!mbox.load(fileName)) {
+            qCWarning(MESSAGEVIEWER_LOG) << "MBOX: Impossible to open file";
+            return false;
+        }
+        mbox.appendMessage(item.payload<KMime::Message::Ptr>());
+
+        if (!mbox.save()) {
+            qCWarning(MESSAGEVIEWER_LOG) << "MBOX: Impossible to save file";
+            return false;
+        }
+        tUrl = QUrl::fromLocalFile(fileName);
+    } else {
+        if (node->header<KMime::Headers::Subject>()) {
+            if (!node->contents().isEmpty()) {
+                node = node->contents().constLast();
+                fileName = window->nodeHelper()->writeNodeToTempFile(node);
+                tUrl = QUrl::fromLocalFile(fileName);
+            }
+        }
+        if (fileName.isEmpty()) {
+            tUrl = window->nodeHelper()->tempFileUrlFromNode(node);
+            fileName = tUrl.path();
         }
     }
-    const QUrl tUrl = window->nodeHelper()->tempFileUrlFromNode(node);
-
-    const QString fileName = tUrl.path();
     if (!fileName.isEmpty()) {
         QFile f(fileName);
         f.setPermissions(
@@ -1057,7 +804,7 @@ bool AttachmentURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) co
         if (!icon.isEmpty()) {
             drag->setPixmap(QIcon::fromTheme(icon).pixmap(16, 16));
         }
-        drag->start();
+        drag->exec();
         return true;
     } else
 #endif
@@ -1094,9 +841,7 @@ QString AttachmentURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *w
     }
     return i18n("Unnamed attachment");
 }
-}
 
-namespace {
 static QString extractAuditLog(const QUrl &url)
 {
     if (url.scheme() != QLatin1String("kmail")
@@ -1140,9 +885,7 @@ bool ShowAuditLogURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window)
     Q_UNUSED(window);
     return true;
 }
-}
 
-namespace {
 bool InternalImageURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) const
 {
     Q_UNUSED(window);
@@ -1156,7 +899,7 @@ bool InternalImageURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window)
 bool InternalImageURLHandler::willHandleDrag(const QUrl &url, ViewerPrivate *window) const
 {
     Q_UNUSED(window);
-    if (url.scheme() == QLatin1String("data") && url.path().startsWith(QStringLiteral("image"))) {
+    if (url.scheme() == QLatin1String("data") && url.path().startsWith(QLatin1String("image"))) {
         return true;
     }
 
@@ -1165,9 +908,7 @@ bool InternalImageURLHandler::willHandleDrag(const QUrl &url, ViewerPrivate *win
                                                      QStandardPaths::LocateDirectory);
     return url.path().contains(imagePath);
 }
-}
 
-namespace {
 bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     const QString scheme(url.scheme());
@@ -1176,7 +917,7 @@ bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
         || (scheme == QLatin1String("ftps")) || (scheme == QLatin1String("sftp"))
         || (scheme == QLatin1String("help")) || (scheme == QLatin1String("vnc"))
         || (scheme == QLatin1String("smb")) || (scheme == QLatin1String("fish"))
-        || (scheme == QLatin1String("news"))) {
+        || (scheme == QLatin1String("news")) || (scheme == QLatin1String("tel"))) {
         KPIM::BroadcastStatus::instance()->setTransientStatusMsg(i18n("Opening URL..."));
         QTimer::singleShot(2000, KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::reset);
 
@@ -1201,17 +942,3 @@ bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
         return false;
     }
 }
-}
-
-bool EmbeddedImageURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) const
-{
-    Q_UNUSED(url);
-    Q_UNUSED(window);
-    return false;
-}
-
-bool EmbeddedImageURLHandler::willHandleDrag(const QUrl &url, ViewerPrivate *window) const
-{
-    Q_UNUSED(window);
-    return url.scheme() == QLatin1String("cid");
-}
