@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,8 +35,8 @@ BlockExternalResourcesUrlInterceptor::~BlockExternalResourcesUrlInterceptor()
 bool BlockExternalResourcesUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
     const QString scheme = info.requestUrl().scheme();
-    if (scheme == QStringLiteral("data")
-        || scheme == QStringLiteral("file")) {
+    if (scheme == QLatin1String("data")
+        || scheme == QLatin1String("file")) {
         return false;
     }
     const QWebEngineUrlRequestInfo::ResourceType resourceType = info.resourceType();
