@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TEST_VIEWVERPLUGIN_GUI_H
-#define TEST_VIEWVERPLUGIN_GUI_H
+#ifndef TEST_VIEWERPLUGIN_GUI_H
+#define TEST_VIEWERPLUGIN_GUI_H
 
 #include <QWidget>
 namespace MessageViewer {
