@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,11 +25,10 @@ class MessageViewer::ViewerPluginPrivate
 {
 public:
     ViewerPluginPrivate()
-        : mEnabled(false)
     {
     }
 
-    bool mEnabled;
+    bool mEnabled = false;
 };
 
 ViewerPlugin::ViewerPlugin(QObject *parent)
