@@ -66,9 +66,7 @@ ConfigureWidget::ConfigureWidget(QWidget *parent)
     d->mSettingsUi->kcfg_ShowExpandQuotesMark->setWhatsThis(
         MessageViewer::MessageViewerSettings::self()->showExpandQuotesMarkItem()->whatsThis());
 
-    connect(d->mSettingsUi->overrideCharacterEncoding,
-            static_cast<void (KComboBox::*)(
-                            int)>(&KComboBox::currentIndexChanged), this,
+    connect(d->mSettingsUi->overrideCharacterEncoding, qOverload<int>(&QComboBox::currentIndexChanged), this,
             &ConfigureWidget::settingsChanged);
 }
 
