@@ -6,8 +6,9 @@
  *  Copyright (c) 2003      Zack Rusin <zack@kde.org>
  *
  *  KMail is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU General Public License, version 2, as
- *  published by the Free Software Foundation.
+ *  under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  KMail is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -47,7 +48,6 @@
 #include <KStandardAction>
 #include <QAction>
 #include <QIcon>
-#include <KIconTheme>
 
 #include <QShortcut>
 #include <QVBoxLayout>
@@ -62,7 +62,7 @@ MailSourceViewTextBrowserWidget::MailSourceViewTextBrowserWidget(const QString &
     : QWidget(parent)
 {
     QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget;
     mTextToSpeechWidget->setObjectName(QStringLiteral("texttospeech"));
     lay->addWidget(mTextToSpeechWidget);
@@ -147,9 +147,6 @@ void MailSourceViewTextBrowser::contextMenuEvent(QContextMenuEvent *event)
         popup->addSeparator();
         popup->addAction(KStandardAction::find(this, &MailSourceViewTextBrowser::findText, this));
         //Code from KTextBrowser
-        KIconTheme::assignIconsToContextMenu(isReadOnly() ? KIconTheme::ReadOnlyText
-                                             : KIconTheme::TextEditor,
-                                             popup->actions());
         if (mTextToSpeechInterface->isReady()) {
             popup->addSeparator();
             popup->addAction(QIcon::fromTheme(QStringLiteral(
