@@ -17,8 +17,8 @@
    02110-1301, USA.
 */
 
-#ifndef __MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H__
-#define __MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H__
+#ifndef MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H
+#define MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H
 
 #include "interfaces/bodypartformatter.h"
 #include "interfaces/bodypart.h"
