@@ -263,6 +263,18 @@ void MessagePart::setIsImage(bool image)
     d->mIsImage = image;
 }
 
+bool MessagePart::hasHeader(const char *header) const
+{
+    Q_UNUSED(header);
+    return false;
+}
+
+KMime::Headers::Base *MimeTreeParser::MessagePart::header(const char *header) const
+{
+    Q_UNUSED(header);
+    return nullptr;
+}
+
 //-----MessagePartList----------------------
 MessagePartList::MessagePartList(ObjectTreeParser *otp)
     : MessagePart(otp, QString())
@@ -329,12 +341,14 @@ void TextMessagePart::parseContent()
          * because mailmain adds an unencrypted part at the end this should not break the overall status
          *
          * That's why we first set the tmp status and if one crypted/signed block comes afterwards, than
-         * the status is set to unencryped
+         * the status is set to unencrypted
          */
         bool fullySignedOrEncrypted = true;
         bool fullySignedOrEncryptedTmp = true;
 
+        int blockIndex = -1;
         for (const auto &block : blocks) {
+            blockIndex += 1;
             if (!fullySignedOrEncryptedTmp) {
                 fullySignedOrEncrypted = false;
             }
@@ -346,6 +360,7 @@ void TextMessagePart::parseContent()
                 EncryptedMessagePart::Ptr mp(new EncryptedMessagePart(mOtp, QString(), cryptProto, fromAddress, nullptr));
                 mp->setDecryptMessage(decryptMessage());
                 mp->setIsEncrypted(true);
+                mp->setMementoName(mp->mementoName() + "-" + nodeHelper()->asHREF(content(), QString::number(blockIndex)).toLocal8Bit());
                 appendSubPart(mp);
                 if (!decryptMessage()) {
                     continue;
@@ -356,6 +371,7 @@ void TextMessagePart::parseContent()
                 }
             } else if (block.type() == ClearsignedBlock) {
                 SignedMessagePart::Ptr mp(new SignedMessagePart(mOtp, QString(), cryptProto, fromAddress, nullptr));
+                mp->setMementoName(mp->mementoName() + "-" + nodeHelper()->asHREF(content(), QString::number(blockIndex)).toLocal8Bit());
                 appendSubPart(mp);
                 mp->startVerification(block.text(), aCodec);
             } else {
@@ -482,6 +498,11 @@ QString HtmlMessagePart::text() const
     return mBodyHTML;
 }
 
+QString MimeTreeParser::HtmlMessagePart::plaintextContent() const
+{
+    return QString();
+}
+
 bool HtmlMessagePart::isHtml() const
 {
     return true;
@@ -547,7 +568,7 @@ AlternativeMessagePart::AlternativeMessagePart(ObjectTreeParser *otp, KMime::Con
         // Still not found? Stupid apple mail actually puts the attachments inside of the
         // multipart/alternative, which is wrong. Therefore we also have to look for multipart/mixed
         // here.
-        // Do this only when prefering HTML mail, though, since otherwise the attachments are hidden
+        // Do this only when preferring HTML mail, though, since otherwise the attachments are hidden
         // when displaying plain text.
         if (!dataHtml) {
             dataHtml = findTypeInDirectChilds(node, "multipart/mixed");
@@ -684,6 +705,7 @@ SignedMessagePart::SignedMessagePart(ObjectTreeParser *otp, const QString &text,
     : MessagePart(otp, text)
     , mCryptoProto(cryptoProto)
     , mFromAddress(fromAddress)
+    , mMementoName("verification")
 {
     setContent(node);
     partMetaData()->technicalProblem = (mCryptoProto == nullptr);
@@ -708,6 +730,16 @@ bool SignedMessagePart::isSigned() const
     return partMetaData()->isSigned;
 }
 
+QByteArray SignedMessagePart::mementoName() const
+{
+    return mMementoName;
+}
+
+void SignedMessagePart::setMementoName(const QByteArray &name)
+{
+    mMementoName = name;
+}
+
 bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signature, KMime::Content *textNode)
 {
     NodeHelper *nodeHelper = mOtp->nodeHelper();
@@ -718,9 +750,9 @@ bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signa
     partMetaData()->status = i18n("Wrong Crypto Plug-In.");
     partMetaData()->status_code = GPGME_SIG_STAT_NONE;
 
-    const QByteArray mementoName = "verification";
+    const QByteArray _mementoName = mementoName();
 
-    CryptoBodyPartMemento *m = dynamic_cast<CryptoBodyPartMemento *>(nodeHelper->bodyPartMemento(content(), mementoName));
+    CryptoBodyPartMemento *m = dynamic_cast<CryptoBodyPartMemento *>(nodeHelper->bodyPartMemento(content(), _mementoName));
     Q_ASSERT(!m || mCryptoProto); //No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
 
     if (!m && mCryptoProto) {
@@ -746,7 +778,7 @@ bool SignedMessagePart::okVerify(const QByteArray &data, const QByteArray &signa
             } else {
                 m->exec();
             }
-            nodeHelper->setBodyPartMemento(content(), mementoName, m);
+            nodeHelper->setBodyPartMemento(content(), _mementoName, m);
         }
     } else if (m && m->isRunning()) {
         partMetaData()->inProgress = true;
@@ -868,7 +900,7 @@ void SignedMessagePart::sigStatusToMetaData()
         }
         for (uint iMail = 0; iMail < key.numUserIDs(); ++iMail) {
             // The following if /should/ always result in TRUE but we
-            // won't trust implicitely the plugin that gave us these data.
+            // won't trust implicitly the plugin that gave us these data.
             if (key.userID(iMail).email()) {
                 QString email = QString::fromUtf8(key.userID(iMail).email());
                 // ### work around gpgme 0.3.QString text() const override;x / cryptplug bug where the
@@ -883,7 +915,7 @@ void SignedMessagePart::sigStatusToMetaData()
         }
 
         if (signature.creationTime()) {
-            partMetaData()->creationTime.setTime_t(signature.creationTime());
+            partMetaData()->creationTime.setSecsSinceEpoch(signature.creationTime());
         } else {
             partMetaData()->creationTime = QDateTime();
         }
@@ -1005,14 +1037,33 @@ QString SignedMessagePart::fromAddress() const
     return mFromAddress;
 }
 
+bool SignedMessagePart::hasHeader(const char *header) const
+{
+    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
+    if (extraContent) {
+        return extraContent->hasHeader(header);
+    }
+    return false;
+}
+
+KMime::Headers::Base *SignedMessagePart::header(const char *header) const
+{
+    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
+    if (extraContent) {
+        return extraContent->headerByType(header);
+    }
+    return nullptr;
+}
+
 //-----CryptMessageBlock---------------------
 EncryptedMessagePart::EncryptedMessagePart(ObjectTreeParser *otp, const QString &text, const QGpgME::Protocol *cryptoProto, const QString &fromAddress, KMime::Content *node)
     : MessagePart(otp, text)
     , mPassphraseError(false)
     , mNoSecKey(false)
+    , mDecryptMessage(false)
     , mCryptoProto(cryptoProto)
     , mFromAddress(fromAddress)
-    , mDecryptMessage(false)
+    , mMementoName("decryptverify")
 {
     setContent(node);
     partMetaData()->technicalProblem = (mCryptoProto == nullptr);
@@ -1064,6 +1115,16 @@ bool EncryptedMessagePart::passphraseError() const
     return mPassphraseError;
 }
 
+QByteArray EncryptedMessagePart::mementoName() const
+{
+    return mMementoName;
+}
+
+void EncryptedMessagePart::setMementoName(const QByteArray &name)
+{
+    mMementoName = name;
+}
+
 void EncryptedMessagePart::startDecryption(const QByteArray &text, const QTextCodec *aCodec)
 {
     KMime::Content *content = new KMime::Content;
@@ -1099,9 +1160,10 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
 
     Q_ASSERT(decryptMessage());
 
+    const QByteArray _mementoName = mementoName();
     // Check whether the memento contains a result from last time:
     const DecryptVerifyBodyPartMemento *m
-        = dynamic_cast<DecryptVerifyBodyPartMemento *>(nodeHelper->bodyPartMemento(&data, "decryptverify"));
+        = dynamic_cast<DecryptVerifyBodyPartMemento *>(nodeHelper->bodyPartMemento(&data, _mementoName));
 
     Q_ASSERT(!m || mCryptoProto); //No CryptoPlugin and having a bodyPartMemento -> there is something completely wrong
 
@@ -1126,7 +1188,7 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
                 newM->exec();
                 m = newM;
             }
-            nodeHelper->setBodyPartMemento(&data, "decryptverify", newM);
+            nodeHelper->setBodyPartMemento(&data, _mementoName, newM);
         }
     } else if (m && m->isRunning()) {
         partMetaData()->inProgress = true;
@@ -1140,7 +1202,7 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
         const GpgME::VerificationResult &verifyResult = m->verifyResult();
         partMetaData()->isSigned = verifyResult.signatures().size() > 0;
 
-        if (verifyResult.signatures().size() > 0) {
+        if (partMetaData()->isSigned) {
             auto subPart = SignedMessagePart::Ptr(new SignedMessagePart(mOtp, MessagePart::text(), mCryptoProto, mFromAddress, content()));
             subPart->setVerificationResult(m, nullptr);
             appendSubPart(subPart);
@@ -1190,6 +1252,11 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
         } else {
             mPassphraseError = decryptResult.error().isCanceled() || decryptResult.error().code() == GPG_ERR_NO_SECKEY;
             partMetaData()->isEncrypted = bDecryptionOk || decryptResult.error().code() != GPG_ERR_NO_DATA;
+
+            if (decryptResult.error().isCanceled()) {
+                setDecryptMessage(false);
+            }
+
             partMetaData()->errorText = QString::fromLocal8Bit(decryptResult.error().asString());
             if (partMetaData()->isEncrypted && decryptResult.numRecipients() > 0) {
                 partMetaData()->keyId = decryptResult.recipient(0).keyID();
@@ -1321,6 +1388,24 @@ const std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key> > &E
     return mDecryptRecipients;
 }
 
+bool EncryptedMessagePart::hasHeader(const char *header) const
+{
+    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
+    if (extraContent) {
+        return extraContent->hasHeader(header);
+    }
+    return false;
+}
+
+KMime::Headers::Base *EncryptedMessagePart::header(const char *header) const
+{
+    const auto extraContent = mOtp->nodeHelper()->decryptedNodeForContent(content());
+    if (extraContent) {
+        return extraContent->headerByType(header);
+    }
+    return nullptr;
+}
+
 EncapsulatedRfc822MessagePart::EncapsulatedRfc822MessagePart(ObjectTreeParser *otp, KMime::Content *node, const KMime::Message::Ptr &message)
     : MessagePart(otp, QString())
     , mMessage(message)
