@@ -20,6 +20,7 @@
 #include "nodehelper.h"
 #include "mimetreeparser_debug.h"
 #include "partmetadata.h"
+#include "messagepart.h"
 #include "interfaces/bodypart.h"
 #include "temporaryfile/attachmenttemporaryfilesdirs.h"
 
@@ -498,6 +499,64 @@ void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
     node->contentType()->setMimeType(mimetype.toLatin1());
 }
 
+bool NodeHelper::hasMailHeader(const char *header, const KMime::Content *message) const
+{
+    return message->hasHeader(header);
+}
+
+KMime::Headers::Base const *NodeHelper::mailHeaderAsBase(const char *header, const KMime::Content *message) const
+{
+    if (mHeaderOverwrite.contains(message)) {
+        foreach (const auto messagePart, mHeaderOverwrite.value(message)) {
+            if (messagePart->hasHeader(header)) {
+                return messagePart->header(header); // Found.
+            }
+        }
+    }
+    return message->headerByType(header);
+}
+
+KMime::Headers::Generics::AddressList const *NodeHelper::mailHeaderAsAddressList(const char *header, const KMime::Content *message) const
+{
+    /* works without this is maybe faster ?
+    if(strcmp(header, "to") == 0) {
+        return message->to();
+    } else if(strcmp(header, "replyTo") == 0) {
+        return message->replyTo();
+    } else if(strcmp(header, "bcc") == 0) {
+        return message->bcc();
+    } else if(strcmp(header, "cc") == 0) {
+        return message->cc();
+    } */
+    auto addressList = new KMime::Headers::Generics::AddressList();
+    const auto hrd = mailHeaderAsBase(header, message);
+    const QByteArray &data = hrd->as7BitString(false);
+    addressList->from7BitString(data);
+    return addressList;
+}
+
+void NodeHelper::clearOverrideHeaders()
+{
+    mHeaderOverwrite.clear();
+}
+
+void NodeHelper::registerOverrideHeader(KMime::Content *message, MessagePart::Ptr part)
+{
+    if (!mHeaderOverwrite.contains(message)) {
+        mHeaderOverwrite[message] = QVector<MessagePart::Ptr>();
+    }
+    mHeaderOverwrite[message].append(part);
+}
+
+QDateTime NodeHelper::dateHeader(KMime::Content *message) const
+{
+    const auto dateHeader = mailHeaderAsBase("date", message);
+    if (dateHeader != nullptr) {
+        return static_cast<const KMime::Headers::Date *>(dateHeader)->dateTime();
+    }
+    return QDateTime();
+}
+
 void NodeHelper::setOverrideCodec(KMime::Content *node, const QTextCodec *codec)
 {
     if (!node) {
@@ -638,10 +697,10 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
             const auto &extraNodes = it.value();
             for (int i = 0; i < extraNodes.size(); i++) {
                 if (extraNodes[i] == node) {
-                    indexStr = QString::fromLatin1("e%1").arg(i);
+                    indexStr = QStringLiteral("e%1").arg(i);
                     const QString parentIndex = persistentIndex(it.key());
                     if (!parentIndex.isEmpty()) {
-                        indexStr = QString::fromLatin1("%1:%2").arg(parentIndex, indexStr);
+                        indexStr = QStringLiteral("%1:%2").arg(parentIndex, indexStr);
                     }
                     return indexStr;
                 }
