@@ -7,8 +7,9 @@
     Copyright (c) 2009 Andras Mantia <andras@kdab.net>
 
     KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
     KMail is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,8 +32,8 @@
     your version.
 */
 
-#ifndef __MIMETREEPARSER_OBJECTTREEPARSER_H__
-#define __MIMETREEPARSER_OBJECTTREEPARSER_H__
+#ifndef MIMETREEPARSER_OBJECTTREEPARSER_H
+#define MIMETREEPARSER_OBJECTTREEPARSER_H
 
 #include "mimetreeparser_export.h"
 
@@ -50,20 +51,19 @@ class Content;
 namespace MimeTreeParser {
 class PartMetaData;
 class ViewerPrivate;
-class HtmlWriter;
-class AttachmentStrategy;
 class NodeHelper;
 class MessagePart;
 class MimeMessagePart;
 
 typedef QSharedPointer<MessagePart> MessagePartPtr;
 typedef QSharedPointer<MimeMessagePart> MimeMessagePartPtr;
-
+/**
+ * @brief The ProcessResult class
+ */
 class MIMETREEPARSER_EXPORT ProcessResult
 {
 public:
-    explicit ProcessResult(NodeHelper *nodeHelper, KMMsgSignatureState inlineSignatureState = KMMsgNotSigned, KMMsgEncryptionState inlineEncryptionState = KMMsgNotEncrypted,
-                           bool neverDisplayInline = false)
+    explicit ProcessResult(NodeHelper *nodeHelper, KMMsgSignatureState inlineSignatureState = KMMsgNotSigned, KMMsgEncryptionState inlineEncryptionState = KMMsgNotEncrypted, bool neverDisplayInline = false)
         : mInlineSignatureState(inlineSignatureState)
         , mInlineEncryptionState(inlineEncryptionState)
         , mNeverDisplayInline(neverDisplayInline)
@@ -124,7 +124,7 @@ processed normally, the processMultipartXXX() functions call stdChildHandling()
 should be handled normally. stdChildHandling() creates its own ObjectTreeParser, which is a clone
 of the current ObjectTreeParser, and processes the node. stdChildHandling() is not called for all
 children of the multipart node, for example processMultiPartAlternativeSubtype() only calls it on
-one of the children, as the other one doesn't need to be displayed. Similary,
+one of the children, as the other one doesn't need to be displayed. Similarly,
 processMultiPartSignedSubtype() doesn't call stdChildHandling() for the signature node, only for the
 signed node.
 
@@ -175,7 +175,7 @@ of the Viewer, which will cause parseObjectTree() to be called again.
 \par Async Crypto Operations
 
 The above case describes decryption the message in place. However, decryption and also verifying of
-the signature can take a long time, so synchronous decryption and verifing would cause the Viewer to
+the signature can take a long time, so synchronous decryption and verifying would cause the Viewer to
 block. Therefore it is possible to run these operations in async mode, see allowAsync().
 In the first run of the async mode, all the ObjectTreeParser does is starting the decrypt or the
 verify job, and informing the user that the operation is in progress with
@@ -247,7 +247,7 @@ yet happened at the time of writing. Therefore the code can seem a bit chaotic.
 
 External plugins are loaded with loadPlugins() in bodypartformatterfactory.cpp. External plugins
 can only use the classes in the interfaces/ directory, they include BodyPart, BodyPartMemento,
-BodyPartFormatterPlugin, BodyPartFormatter, BodyPartURLHandler, HtmlWriter and URLHandler. Therefore
+BodyPartFormatterPlugin, BodyPartFormatter, BodyPartURLHandler and URLHandler. Therefore
 external plugins have powerful capabilities, which are needed for example in the iCal formatter or
 in the vCard formatter.
 
@@ -270,9 +270,9 @@ class MIMETREEPARSER_EXPORT ObjectTreeParser
     ObjectTreeParser(const ObjectTreeParser &other);
 
 public:
-    explicit ObjectTreeParser(Interface::ObjectTreeSource *source, NodeHelper *nodeHelper = nullptr, bool showOneMimePart = false, const AttachmentStrategy *attachmentStrategy = nullptr);
+    explicit ObjectTreeParser(Interface::ObjectTreeSource *source, NodeHelper *nodeHelper = nullptr);
 
-    explicit ObjectTreeParser(const ObjectTreeParser *topLevelParser, bool showOneMimePart = false, const AttachmentStrategy *attachmentStrategy = nullptr);
+    explicit ObjectTreeParser(const ObjectTreeParser *topLevelParser);
     virtual ~ObjectTreeParser();
 
     void setAllowAsync(bool allow);
@@ -290,7 +290,7 @@ public:
     /**
     * Similar to plainTextContent(), but returns the HTML source of the first text/html MIME part.
     *
-    * Not to be consfused with the HTML code that the message viewer widget displays, that HTML
+    * Not to be confused with the HTML code that the message viewer widget displays, that HTML
     * is written out by htmlWriter() and a totally different pair of shoes.
     */
     QString htmlContent() const;
@@ -304,18 +304,11 @@ public:
     QByteArray plainTextContentCharset() const;
     QByteArray htmlContentCharset() const;
 
-    bool showOnlyOneMimePart() const;
-    void setShowOnlyOneMimePart(bool show);
-
-    const AttachmentStrategy *attachmentStrategy() const;
-
-    HtmlWriter *htmlWriter() const;
-
     NodeHelper *nodeHelper() const;
 
     /** Parse beginning at a given node and recursively parsing
       the children of that node and it's next sibling. */
-    void parseObjectTree(KMime::Content *node);
+    void parseObjectTree(KMime::Content *node, bool parseOnlySingleNode = false);
     MessagePartPtr parsedPart() const;
 
 private:
@@ -336,12 +329,9 @@ private:
 
     const QTextCodec *codecFor(KMime::Content *node) const;
 
-    void copyContentFrom(const ObjectTreeParser *other);
-
 private:
     Interface::ObjectTreeSource *mSource;
     NodeHelper *mNodeHelper;
-    HtmlWriter *mHtmlWriter;
     QByteArray mPlainTextContentCharset;
     QByteArray mHtmlContentCharset;
     QString mPlainTextContent;
@@ -354,7 +344,7 @@ private:
     /// children. If that is the case, this variable is set to true.
     /// The code needs to behave differently if this is set. For example, it should not process the
     /// siblings. Also, consider inline images: Normally, those nodes are completely hidden, as the
-    /// HTML node embedds them. However, when showing only the node of the image, one has to show them,
+    /// HTML node embeds them. However, when showing only the node of the image, one has to show them,
     /// as their is no HTML node in which they are displayed. There are many more cases where this
     /// variable needs to be obeyed.
     /// This variable is set to false again when processing the children in stdChildHandling(), as
@@ -363,7 +353,6 @@ private:
 
     bool mHasPendingAsyncJobs;
     bool mAllowAsync;
-    const AttachmentStrategy *mAttachmentStrategy;
     // DataUrl Icons cache
     QString mCollapseIcon;
     QString mExpandIcon;
@@ -380,4 +369,4 @@ private:
 };
 }
 
-#endif // __MIMETREEPARSER_OBJECTTREEPARSER_H__
+#endif // MIMETREEPARSER_OBJECTTREEPARSER_H
