@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "customtemplatesmenutest.h"
 #include "customtemplatesmenu.h"
 #include <kactioncollection.h>
-#include <qtest.h>
+#include <QTest>
 
 CustomTemplatesMenuTest::CustomTemplatesMenuTest(QObject *parent)
     : QObject(parent)
