@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,8 +25,8 @@
 #include "templateparserextracthtmlinforesult.h"
 
 namespace TemplateParser {
-class TemplateWebEngineView;
-class TemplateExtractHtmlElementWebEngineView;
+class TemplateExtractTextFromMail;
+class TemplateExtractHtmlElementFromMail;
 
 class TEMPLATEPARSER_TESTS_EXPORT TemplateParserExtractHtmlInfo : public QObject
 {
@@ -54,8 +54,8 @@ private:
 
     QString mTemplateStr;
 
-    TemplateWebEngineView *mTemplateWebEngineView = nullptr;
-    TemplateExtractHtmlElementWebEngineView *mExtractHtmlElementWebEngineView = nullptr;
+    TemplateExtractTextFromMail *mTemplateWebEngineView = nullptr;
+    TemplateExtractHtmlElementFromMail *mExtractHtmlElementWebEngineView = nullptr;
 };
 }
 #endif // TEMPLATEPARSEREXTRACTHTMLINFO_H
