@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,19 +17,15 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "templatescommandmenu.h"
 
 #include <QAction>
 #include <KActionMenu>
 #include "templateparser_debug.h"
 #include <KLocalizedString>
-#include <QAction>
 
 #undef I18N_NOOP
 #define I18N_NOOP(t) nullptr, t
-#undef I18N_NOOP2
-#define I18N_NOOP2(c, t) c, t
 
 using namespace TemplateParser;
 
@@ -161,7 +157,7 @@ static const InsertCommand originalCommands[] = {
     },
 
     {
-        I18N_NOOP2("Template value for subject of the message", "Subject"),
+        I18NC_NOOP("Template value for subject of the message", "Subject"),
         TemplatesCommandMenu::COFullSubject
     },
 
@@ -289,7 +285,7 @@ static const InsertCommand currentCommands[] = {
     },
 
     {
-        I18N_NOOP2("Template subject command.", "Subject"),
+        I18NC_NOOP("Template subject command.", "Subject"),
         TemplatesCommandMenu::CFullSubject
     },
 
@@ -332,7 +328,7 @@ static const int extCommandsCount
 
 static const InsertCommand miscCommands[] = {
     {
-        I18N_NOOP2("Inserts user signature, also known as footer, into message", "Signature"),
+        I18NC_NOOP("Inserts user signature, also known as footer, into message", "Signature"),
         TemplatesCommandMenu::CSignature
     },
 
@@ -342,7 +338,7 @@ static const InsertCommand miscCommands[] = {
     },
 
     {
-        I18N_NOOP2("All characters, up to and including the next newline, "
+        I18NC_NOOP("All characters, up to and including the next newline, "
                    "are discarded without performing any macro expansion",
                    "Discard to Next Line"),
         TemplatesCommandMenu::CDnl
@@ -384,7 +380,6 @@ static const InsertCommand miscCommands[] = {
 };
 static const int miscCommandsCount = sizeof(miscCommands) / sizeof(*miscCommands);
 
-
 static const InsertCommand debugCommands[] = {
     {
         I18N_NOOP("Turn Debug On"),
@@ -406,7 +401,9 @@ void TemplatesCommandMenu::fillMenuFromActionMap(const QMap< QString, TemplatesC
     while (it != end) {
         QAction *action = new QAction(it.key(), menu);   //krazy:exclude=tipsandthis
         const TemplatesCommandMenu::Command cmd = it.value();
-        connect(action, &QAction::triggered, this, [this, cmd]{ slotInsertCommand(cmd); });
+        connect(action, &QAction::triggered, this, [this, cmd] {
+            slotInsertCommand(cmd);
+        });
         menu->addAction(action);
         ++it;
     }
@@ -419,7 +416,6 @@ TemplatesCommandMenu::TemplatesCommandMenu(QObject *parent)
 
 TemplatesCommandMenu::~TemplatesCommandMenu()
 {
-
 }
 
 QMenu *TemplatesCommandMenu::menu() const
@@ -506,7 +502,6 @@ void TemplatesCommandMenu::fillSubMenus()
             fillMenuFromActionMap(commandMap, menu);
         }
     }
-
 }
 
 TemplatesCommandMenu::MenuTypes TemplatesCommandMenu::type() const
