@@ -1,11 +1,12 @@
 /*
-  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-  This progam is distributed in the hope that it will be useful, but
+  This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
@@ -19,11 +20,13 @@
 #define TEMPLATEPARSER_TEMPLATESUTIL_H
 
 #include "templateparser_export.h"
+#include <QString>
 
-class QString;
 namespace TemplateParser {
 namespace Util {
 TEMPLATEPARSER_EXPORT void deleteTemplate(const QString &id);
+TEMPLATEPARSER_EXPORT Q_REQUIRED_RESULT QString getLastNameFromEmail(const QString &str);
+TEMPLATEPARSER_EXPORT Q_REQUIRED_RESULT QString getFirstNameFromEmail(const QString &str);
 }
 }
 
