@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -90,7 +90,7 @@ void CheckPhishingUrlJobTest::shouldParseResult()
 
     WebEngineViewer::CheckPhishingUrlJob job;
     job.setUrl(checkedUrl);
-    QSignalSpy spy1(&job, SIGNAL(result(WebEngineViewer::CheckPhishingUrlUtil::UrlStatus,QUrl,uint)));
+    QSignalSpy spy1(&job, &WebEngineViewer::CheckPhishingUrlJob::result);
     job.parse(input);
     QCOMPARE(spy1.count(), 1);
     QCOMPARE(spy1.at(0).at(0).value<WebEngineViewer::CheckPhishingUrlUtil::UrlStatus>(), urlStatus);
