@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,9 +34,7 @@ class WebEngineViewer::LocalDataBaseFilePrivate
 public:
     LocalDataBaseFilePrivate(const QString &filename, LocalDataBaseFile *qq)
         : mFile(filename)
-        , mData(nullptr)
         , q(qq)
-        , mValid(false)
     {
     }
 
@@ -46,10 +44,10 @@ public:
 
     QElapsedTimer mLastCheck;
     QFile mFile;
-    uchar *mData;
+    uchar *mData = nullptr;
     QDateTime mMtime;
     LocalDataBaseFile *q;
-    bool mValid;
+    bool mValid = false;
 };
 
 bool LocalDataBaseFilePrivate::load()
