@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CHECKPHISHINGURLGUI_H
-#define CHECKPHISHINGURLGUI_H
+#ifndef SEARCHFULLHASHGUI_H
+#define SEARCHFULLHASHGUI_H
 
 #include <QWidget>
 #include "../searchfullhashjob.h"
@@ -41,4 +41,4 @@ private:
     QPlainTextEdit *mResult;
 };
 
-#endif // CHECKPHISHINGURLGUI_H
+#endif // SEARCHFULLHASHGUI_H
