@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TestSelectionChangedEngine_H
-#define TestSelectionChangedEngine_H
+#ifndef TestSelectionChangedWebEngine_H
+#define TestSelectionChangedWebEngine_H
 
 #include <QWidget>
 
@@ -38,4 +38,4 @@ private:
     WebEngineViewer::WebEngineView *pageView;
 };
 
-#endif // TestSelectionChangedEngine_H
+#endif // TestSelectionChangedWebEngine_H
